# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FILE_INFORMATION_METADATA = Metadata(
    id="f864ba42ad5e68fac32ba7e06c7a8d85190c2331.boutiques",
    name="file-information",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class FileInformationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `file_information(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def file_information(
    data_file: str,
    opt_no_map_info: bool = False,
    opt_only_step_interval: bool = False,
    opt_only_number_of_maps: bool = False,
    opt_only_map_names: bool = False,
    opt_only_metadata: bool = False,
    opt_key_key: str | None = None,
    opt_only_cifti_xml: bool = False,
    opt_czi: bool = False,
    opt_czi_all_sub_blocks: bool = False,
    opt_czi_xml: bool = False,
    runner: Runner | None = None,
) -> FileInformationOutputs:
    """
    List information about a file's content.
    
    List information about the content of a data file. Only one -only option may
    be specified. The information listed when no -only option is present is
    dependent upon the type of data file.
    
    Library paths:
    /usr/lib/x86_64-linux-gnu/qt5/plugins
    
    /mnt/c/Users/floru/Projects/cmi/nopype/extraction/workbench/source/build/CommandLine
    
    
    File and extensions for reading and writing:
    Annotation: wb_annot
    Annotation Text Substitution: wb_annsub.csv
    Border: border, wb_border
    CIFTI - Dense: dconn.nii
    CIFTI - Dense Label: dlabel.nii
    CIFTI - Dense Parcel: dpconn.nii
    CIFTI - Dense Scalar: dscalar.nii
    CIFTI - Dense Data Series: dtseries.nii
    CIFTI - Fiber Orientations TEMPORARY: fiberTEMP.nii
    CIFTI - Fiber Trajectory TEMPORARY: trajTEMP.wbsparse
    CIFTI - Parcel: pconn.nii
    CIFTI - Parcel Dense: pdconn.nii
    CIFTI - Parcel Label: plabel.nii
    CIFTI - Parcel Scalar: pscalar.nii
    CIFTI - Parcel Series: ptseries.nii
    CIFTI - Scalar Data Series: sdseries.nii
    CZI Image: czi
    Foci: foci, wb_foci
    Histology Slices: metaczi, meta-image
    Image Read: bmp, gif, jpeg, jpg, png, ppm
    Write: bmp, jpeg, jpg, png, ppm
    Label: label.gii
    Metric: func.gii, shape.gii
    Palette: palette, wb_palette
    RGBA: rgba.gii
    Samples: wb_samples
    Scene: scene, wb_scene
    Specification: spec, wb_spec
    Surface: surf.gii
    Volume: nii, nii.gz
    .
    
    Author: Washington University School of Medicin
    
    Args:
        data_file: data file.
        opt_no_map_info: do not show map information for files that support\
            maps.
        opt_only_step_interval: suppress normal output, print the interval\
            between maps.
        opt_only_number_of_maps: suppress normal output, print the number of\
            maps.
        opt_only_map_names: suppress normal output, print the names of all maps.
        opt_only_metadata: suppress normal output, print file metadata.
        opt_key_key: only print the metadata for one key, with no formatting:\
            the metadata key.
        opt_only_cifti_xml: suppress normal output, print the cifti xml if the\
            file type has it.
        opt_czi: For a CZI file, show information from the libCZI Info Command\
            instead of the Workbench CZI File.
        opt_czi_all_sub_blocks: show all sub-blocks in CZI file (may produce\
            long output).
        opt_czi_xml: show XML from CZI file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FileInformationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FILE_INFORMATION_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-file-information")
    cargs.append(data_file)
    if opt_no_map_info:
        cargs.append("-no-map-info")
    if opt_only_step_interval:
        cargs.append("-only-step-interval")
    if opt_only_number_of_maps:
        cargs.append("-only-number-of-maps")
    if opt_only_map_names:
        cargs.append("-only-map-names")
    if opt_only_metadata:
        cargs.append("-only-metadata")
    if opt_key_key is not None:
        cargs.extend([
            "-key",
            opt_key_key
        ])
    if opt_only_cifti_xml:
        cargs.append("-only-cifti-xml")
    if opt_czi:
        cargs.append("-czi")
    if opt_czi_all_sub_blocks:
        cargs.append("-czi-all-sub-blocks")
    if opt_czi_xml:
        cargs.append("-czi-xml")
    ret = FileInformationOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FILE_INFORMATION_METADATA",
    "FileInformationOutputs",
    "file_information",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ZREGRID_METADATA = Metadata(
    id="583bc31cb0a63645cc46045fc858a11419ef47bc.boutiques",
    name="3dZregrid",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dZregridOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_zregrid(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile_head: OutputPathType | None
    """Output dataset with new grid"""
    outfile_brik: OutputPathType | None
    """Output dataset with new grid"""


def v_3d_zregrid(
    infile: InputPathType,
    z_thickness: float | None = None,
    slice_count: float | None = None,
    z_size: float | None = None,
    prefix: str | None = None,
    verbose: bool = False,
    runner: Runner | None = None,
) -> V3dZregridOutputs:
    """
    Alters the input dataset's slice thickness and/or number.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dZregrid.html
    
    Args:
        infile: Input dataset.
        z_thickness: Set slice thickness to D mm.
        slice_count: Set slice count to N.
        z_size: Set thickness of dataset (center-to-center of first and last\
            slices) to Z mm.
        prefix: Write result to dataset with prefix P.
        verbose: Write progress reports to stderr.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dZregridOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ZREGRID_METADATA)
    cargs = []
    cargs.append("3dZregrid")
    if z_thickness is not None:
        cargs.extend([
            "-dz",
            str(z_thickness)
        ])
    if slice_count is not None:
        cargs.extend([
            "-nz",
            str(slice_count)
        ])
    if z_size is not None:
        cargs.extend([
            "-zsize",
            str(z_size)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    cargs.append(execution.input_file(infile))
    if verbose:
        cargs.append("-verb")
    ret = V3dZregridOutputs(
        root=execution.output_file("."),
        outfile_head=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
        outfile_brik=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dZregridOutputs",
    "V_3D_ZREGRID_METADATA",
    "v_3d_zregrid",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_MATH_METADATA = Metadata(
    id="dc07516afa612a64f752715f1bdec0c3ee8f33a2.boutiques",
    name="metric-math",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class MetricMathVar:
    """
    a metric to use as a variable.
    """
    name: str
    """the name of the variable, as used in the expression"""
    metric: InputPathType
    """the metric file to use as this variable"""
    opt_column_column: str | None = None
    """select a single column: the column number or name"""
    opt_repeat: bool = False
    """reuse a single column for each column of calculation"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-var")
        cargs.append(self.name)
        cargs.append(execution.input_file(self.metric))
        if self.opt_column_column is not None:
            cargs.extend([
                "-column",
                self.opt_column_column
            ])
        if self.opt_repeat:
            cargs.append("-repeat")
        return cargs


class MetricMathOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_math(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_math(
    expression: str,
    metric_out: str,
    opt_fixnan_replace: float | None = None,
    var: list[MetricMathVar] | None = None,
    runner: Runner | None = None,
) -> MetricMathOutputs:
    """
    Evaluate expression on metric files.
    
    This command evaluates <expression> at each surface vertex independently.
    There must be at least one -var option (to get the structure, number of
    vertices, and number of columns from), even if the <name> specified in it
    isn't used in <expression>. All metrics must have the same number of
    vertices. Filenames are not valid in <expression>, use a variable name and a
    -var option with matching <name> to specify an input file. If the -column
    option is given to any -var option, only one column is used from that file.
    If -repeat is specified, the file must either have only one column, or have
    the -column option specified. All files that don't use -repeat must have the
    same number of columns requested to be used. The format of <expression> is
    as follows:
    
    Expressions consist of constants, variables, operators, parentheses, and
    functions, in infix notation, such as 'exp(-x + 3) * scale'. Variables are
    strings of any length, using the characters a-z, A-Z, 0-9, and _, but may
    not take the name of a named constant. Currently, there is only one named
    constant, PI. The operators are +, -, *, /, ^, >, <, >=, <=, ==, !=, !, &&,
    ||. These behave as in C, except that ^ is exponentiation, i.e. pow(x, y),
    and takes higher precedence than other binary operators (also, '-3^-4^-5'
    means '-(3^(-(4^-5)))'). The <=, >=, ==, and != operators are given a small
    amount of wiggle room, equal to one millionth of the smaller of the absolute
    values of the values being compared.
    
    Comparison and logical operators return 0 or 1, you can do masking with
    expressions like 'x * (mask > 0)'. For all logical operators, an input is
    considered true iff it is greater than 0. The expression '0 < x < 5' is not
    syntactically wrong, but it will NOT do what is desired, because it is
    evaluated left to right, i.e. '((0 < x) < 5)', which will always return 1,
    as both possible results of a comparison are less than 5. A warning is
    generated if an expression of this type is detected. Use something like 'x >
    0 && x < 5' to get the desired behavior.
    
    Whitespace between elements is ignored, ' sin ( 2 * x ) ' is equivalent to
    'sin(2*x)', but 's in(2*x)' is an error. Implied multiplication is not
    allowed, the expression '2x' will be parsed as a variable. Parentheses are
    (), do not use [] or {}. Functions require parentheses, the expression 'sin
    x' is an error.
    
    The following functions are supported:
    
    sin: 1 argument, the sine of the argument (units are radians)
    cos: 1 argument, the cosine of the argument (units are radians)
    tan: 1 argument, the tangent of the argument (units are radians)
    asin: 1 argument, the inverse of sine of the argument, in radians
    acos: 1 argument, the inverse of cosine of the argument, in radians
    atan: 1 argument, the inverse of tangent of the argument, in radians
    atan2: 2 arguments, atan2(y, x) returns the inverse of tangent of (y/x), in
    radians, determining quadrant by the sign of both arguments
    sinh: 1 argument, the hyperbolic sine of the argument
    cosh: 1 argument, the hyperbolic cosine of the argument
    tanh: 1 argument, the hyperbolic tangent of the argument
    asinh: 1 argument, the inverse hyperbolic sine of the argument
    acosh: 1 argument, the inverse hyperbolic cosine of the argument
    atanh: 1 argument, the inverse hyperbolic tangent of the argument
    sinc: 1 argument, sinc(0) = 1, sin(x) / x otherwise
    ln: 1 argument, the natural logarithm of the argument
    exp: 1 argument, the constant e raised to the power of the argument
    log: 1 argument, the base 10 logarithm of the argument
    log2: 1 argument, the base 2 logarithm of the argument
    sqrt: 1 argument, the square root of the argument
    abs: 1 argument, the absolute value of the argument
    floor: 1 argument, the largest integer not greater than the argument
    round: 1 argument, the nearest integer, with ties rounded away from zero
    ceil: 1 argument, the smallest integer not less than the argument
    min: 2 arguments, min(x, y) returns y if (x > y), x otherwise
    max: 2 arguments, max(x, y) returns y if (x < y), x otherwise
    mod: 2 arguments, mod(x, y) = x - y * floor(x / y), or 0 if y == 0
    clamp: 3 arguments, clamp(x, low, high) = min(max(x, low), high)
    .
    
    Author: Washington University School of Medicin
    
    Args:
        expression: the expression to evaluate, in quotes.
        metric_out: the output metric.
        opt_fixnan_replace: replace NaN results with a value: value to replace\
            NaN with.
        var: a metric to use as a variable.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricMathOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_MATH_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-math")
    cargs.append(expression)
    cargs.append(metric_out)
    if opt_fixnan_replace is not None:
        cargs.extend([
            "-fixnan",
            str(opt_fixnan_replace)
        ])
    if var is not None:
        cargs.extend([a for c in [s.run(execution) for s in var] for a in c])
    ret = MetricMathOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_MATH_METADATA",
    "MetricMathOutputs",
    "MetricMathVar",
    "metric_math",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRSI_SEGMENT_METADATA = Metadata(
    id="68c36b893349987e43bfd6044eeb59ccd2b7cef2.boutiques",
    name="mrsi_segment",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class MrsiSegmentOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mrsi_segment(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file name"""


def mrsi_segment(
    mrsi_file: InputPathType,
    runner: Runner | None = None,
) -> MrsiSegmentOutputs:
    """
    FSL Magnetic Resonance Spectroscopy - register fast segmentation to MRSI.
    
    Author: FSL Team
    
    Args:
        mrsi_file: MRSI nifti file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrsiSegmentOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRSI_SEGMENT_METADATA)
    cargs = []
    cargs.append("mrsi_segment")
    cargs.append(execution.input_file(mrsi_file))
    cargs.append("[--t1")
    cargs.append("T1]")
    cargs.append("[--anat")
    cargs.append("ANAT]")
    cargs.append("[--output")
    cargs.append("OUTPUT]")
    cargs.append("[--filename")
    cargs.append("FILENAME]")
    ret = MrsiSegmentOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[--output]/[--filename]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRSI_SEGMENT_METADATA",
    "MrsiSegmentOutputs",
    "mrsi_segment",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UNCONFOUND_METADATA = Metadata(
    id="15eb9fd545daea054e512faf9fe43e4f920e55e0.boutiques",
    name="unconfound",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class UnconfoundOutputs(typing.NamedTuple):
    """
    Output object returned when calling `unconfound(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_4d: OutputPathType
    """Output 4D fMRI data after removing confounds"""


def unconfound(
    in4d: InputPathType,
    out4d: str,
    confound_mat: InputPathType,
    runner: Runner | None = None,
) -> UnconfoundOutputs:
    """
    Removing confounds from 4D fMRI data.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FSL
    
    Args:
        in4d: Input 4D fMRI data (e.g., in4d.nii.gz).
        out4d: Output 4D fMRI data after removing confounds (e.g.,\
            out4d.nii.gz).
        confound_mat: Confound matrix file (e.g., confound.mat).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `UnconfoundOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UNCONFOUND_METADATA)
    cargs = []
    cargs.append("unconfound")
    cargs.append(execution.input_file(in4d))
    cargs.append(out4d)
    cargs.append(execution.input_file(confound_mat))
    ret = UnconfoundOutputs(
        root=execution.output_file("."),
        output_4d=execution.output_file(out4d + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UNCONFOUND_METADATA",
    "UnconfoundOutputs",
    "unconfound",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLORIENT_METADATA = Metadata(
    id="3db0f2ea413348594ebb2a3a46459edace358fe2.boutiques",
    name="fslorient",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslorientOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslorient(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fslorient(
    filename: InputPathType,
    swap_orient: bool = False,
    runner: Runner | None = None,
) -> FslorientOutputs:
    """
    FSL tool to manipulate NIfTI header orientation information.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        filename: Filename of the image to operate on (e.g. img.nii.gz).
        swap_orient: Swaps FSL radiological and FSL neurological.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslorientOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLORIENT_METADATA)
    cargs = []
    cargs.append("fslorient")
    if swap_orient:
        cargs.append("-swaporient")
    cargs.append(execution.input_file(filename))
    ret = FslorientOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLORIENT_METADATA",
    "FslorientOutputs",
    "fslorient",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_MRS_SIM_METADATA = Metadata(
    id="d8751192080281b952d5e68a6abe3ed8ca8d7fdd.boutiques",
    name="fsl_mrs_sim",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslMrsSimOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_mrs_sim(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    generated_output: OutputPathType | None
    """Generated output files based on provided parameters"""


def fsl_mrs_sim(
    sequence_file: InputPathType,
    metab: str,
    metab_file: InputPathType,
    custom_spinsys: InputPathType,
    output_folder: str | None = None,
    raw_flag: bool = False,
    jmru_flag: bool = False,
    addref_flag: bool = False,
    autophase_ppm: float | None = None,
    lcm_loc: str | None = None,
    mm_json: InputPathType | None = None,
    output_te: float | None = None,
    overwrite_flag: bool = False,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> FslMrsSimOutputs:
    """
    FSL Magnetic Resonance Spectroscopy Simulation Tool.
    
    Author: FSL
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/fsl_mrs
    
    Args:
        sequence_file: Pulse sequence file or previous results file.
        metab: Single metabolite string.
        metab_file: Path to file containing metabolite list for batch\
            simulation.
        custom_spinsys: Path to JSON file containing custom spin systems.
        output_folder: Output folder.
        raw_flag: Output LCModel Style Raw files.
        jmru_flag: Output jMRUI Style txt files.
        addref_flag: Add 0 ppm reference to all outputs.
        autophase_ppm: Simulate a singlet peak at <ppm> to auto-phase the basis\
            spectra. Relative to receiver central frequency.
        lcm_loc: Location to enter into lcm IN file.
        mm_json: JSON file containing MM FID to add to the basis output.
        output_te: Echo time value in ms for output files (no effect on\
            simulation).
        overwrite_flag: Overwrite existing output folder.
        verbose_flag: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslMrsSimOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_MRS_SIM_METADATA)
    cargs = []
    cargs.append("fsl_mrs_sim")
    cargs.append(execution.input_file(sequence_file))
    cargs.extend([
        "-m",
        metab
    ])
    cargs.extend([
        "-b",
        execution.input_file(metab_file)
    ])
    cargs.extend([
        "-s",
        execution.input_file(custom_spinsys)
    ])
    if output_folder is not None:
        cargs.extend([
            "-o",
            output_folder
        ])
    if raw_flag:
        cargs.append("-r")
    if jmru_flag:
        cargs.append("-j")
    if addref_flag:
        cargs.append("-a")
    if autophase_ppm is not None:
        cargs.extend([
            "-p",
            str(autophase_ppm)
        ])
    if lcm_loc is not None:
        cargs.extend([
            "--lcmIN",
            lcm_loc
        ])
    if mm_json is not None:
        cargs.extend([
            "--MM",
            execution.input_file(mm_json)
        ])
    if output_te is not None:
        cargs.extend([
            "-e",
            str(output_te)
        ])
    if overwrite_flag:
        cargs.append("--overwrite")
    if verbose_flag:
        cargs.append("--verbose")
    ret = FslMrsSimOutputs(
        root=execution.output_file("."),
        generated_output=execution.output_file(output_folder + "/<generated_file>") if (output_folder is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_MRS_SIM_METADATA",
    "FslMrsSimOutputs",
    "fsl_mrs_sim",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TSGEN_METADATA = Metadata(
    id="410ba1425e90c9f623bd605b045f173958077c32.boutiques",
    name="3dTSgen",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTsgenOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tsgen(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_tsgen(
    input_file: InputPathType,
    signal_label: str,
    noise_label: str,
    sigma_value: float,
    output_file: str,
    in_tr_flag: bool = False,
    signal_constr: str | None = None,
    noise_constr: str | None = None,
    voxel_number: float | None = None,
    signal_coef: str | None = None,
    noise_coef: str | None = None,
    bucket_config: str | None = None,
    runner: Runner | None = None,
) -> V3dTsgenOutputs:
    """
    This program generates an AFNI 3d+time data set based on user-specified signal
    and noise models for each voxel.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTSgen.html
    
    Args:
        input_file: Filename of prototype 3d + time data file.
        signal_label: Name of the (non-linear) signal model.
        noise_label: Name of the (linear) noise model.
        sigma_value: Standard deviation of additive Gaussian noise.
        output_file: Filename of output 3d + time data file.
        in_tr_flag: Set the TR of the created timeseries to be the TR of the\
            prototype dataset. The default is TR = 1.
        signal_constr: Constraints for kth signal parameter. Format: k c d\
            where c <= gs[k] <= d.
        noise_constr: Constraints for kth noise parameter. Format: k c d where\
            c+b[k] <= gn[k] <= d+b[k].
        voxel_number: Screen output for voxel number.
        signal_coef: Write kth signal parameter gs[k]. Output 'fim' is written\
            to prefix filename.
        noise_coef: Write kth noise parameter gn[k]. Output 'fim' is written to\
            prefix filename.
        bucket_config: Create one AFNI 'bucket' dataset containing n\
            sub-bricks. n=0 creates the default output. Output 'bucket' is written\
            to prefixname.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTsgenOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TSGEN_METADATA)
    cargs = []
    cargs.append("3dTSgen")
    cargs.append(execution.input_file(input_file))
    if in_tr_flag:
        cargs.append("-inTR")
    cargs.extend([
        "-signal",
        signal_label
    ])
    cargs.extend([
        "-noise",
        noise_label
    ])
    if signal_constr is not None:
        cargs.extend([
            "-sconstr",
            signal_constr
        ])
    if noise_constr is not None:
        cargs.extend([
            "-nconstr",
            noise_constr
        ])
    cargs.extend([
        "-sigma",
        str(sigma_value)
    ])
    if voxel_number is not None:
        cargs.extend([
            "-voxel",
            str(voxel_number)
        ])
    cargs.extend([
        "-output",
        output_file
    ])
    if signal_coef is not None:
        cargs.extend([
            "-scoef",
            signal_coef
        ])
    if noise_coef is not None:
        cargs.extend([
            "-ncoef",
            noise_coef
        ])
    if bucket_config is not None:
        cargs.extend([
            "-bucket",
            bucket_config
        ])
    ret = V3dTsgenOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTsgenOutputs",
    "V_3D_TSGEN_METADATA",
    "v_3d_tsgen",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_LABEL_MODIFY_KEYS_METADATA = Metadata(
    id="3e9e975ebe915117d571b9514f44747025005713.boutiques",
    name="volume-label-modify-keys",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class VolumeLabelModifyKeysOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_label_modify_keys(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume label file"""


def volume_label_modify_keys(
    volume_in: InputPathType,
    remap_file: str,
    volume_out: str,
    opt_subvolume_subvolume: str | None = None,
    runner: Runner | None = None,
) -> VolumeLabelModifyKeysOutputs:
    """
    Change key values in a volume label file.
    
    <remap-file> should have lines of the form 'oldkey newkey', like so:
    
    3 5
    5 8
    8 2
    
    This would change the current label with key '3' to use the key '5' instead,
    5 would use 8, and 8 would use 2. Any collision in key values results in the
    label that was not specified in the remap file getting remapped to an
    otherwise unused key. Remapping more than one key to the same new key, or
    the same key to more than one new key, results in an error. This will not
    change the appearance of the file when displayed, as it will change the key
    values in the data at the same time.
    
    Author: Washington University School of Medicin
    
    Args:
        volume_in: the input volume label file.
        remap_file: text file with old and new key values.
        volume_out: the output volume label file.
        opt_subvolume_subvolume: select a single subvolume: the subvolume\
            number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeLabelModifyKeysOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_LABEL_MODIFY_KEYS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-label-modify-keys")
    cargs.append(execution.input_file(volume_in))
    cargs.append(remap_file)
    cargs.append(volume_out)
    if opt_subvolume_subvolume is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvolume
        ])
    ret = VolumeLabelModifyKeysOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_LABEL_MODIFY_KEYS_METADATA",
    "VolumeLabelModifyKeysOutputs",
    "volume_label_modify_keys",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

XTRACT_VIEWER_METADATA = Metadata(
    id="bd76f729ac54b26b22e247a3422cd7082ceff910.boutiques",
    name="xtract_viewer",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class XtractViewerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `xtract_viewer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def xtract_viewer(
    xtract_dir: str,
    species: typing.Literal["HUMAN", "MACAQUE"] | None = None,
    brain_image: InputPathType | None = None,
    structures: str | None = None,
    thresholds: list[float] | None = None,
    runner: Runner | None = None,
) -> XtractViewerOutputs:
    """
    Viewer tool for XTRACT output.
    
    Author: FMRIB Centre, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/XTRACT
    
    Args:
        xtract_dir: Path to XTRACT output folder.
        species: Species type (HUMAN or MACAQUE).
        brain_image: The brain image to use for the background overlay - must\
            be in the same space as tracts. Default is the FSL_HCP065_FA map for\
            HUMAN and F99 T1 brain for MACAQUE.
        structures: Structures (comma separated, default = display all that is\
            found in input folder).
        thresholds: The lower and upper thresholds applied to the tracts for\
            viewing. Default = 0.001 0.1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `XtractViewerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(XTRACT_VIEWER_METADATA)
    cargs = []
    cargs.append("xtract_viewer")
    cargs.append("-dir")
    cargs.extend([
        "-dir",
        xtract_dir
    ])
    if species is not None:
        cargs.extend([
            "-species",
            species
        ])
    if brain_image is not None:
        cargs.extend([
            "-brain",
            execution.input_file(brain_image)
        ])
    if structures is not None:
        cargs.extend([
            "-str",
            structures
        ])
    if thresholds is not None:
        cargs.extend([
            "-thr",
            *map(str, thresholds)
        ])
    ret = XtractViewerOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "XTRACT_VIEWER_METADATA",
    "XtractViewerOutputs",
    "xtract_viewer",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_GRADIENT_METADATA = Metadata(
    id="216ceddd1af371fb04990774f70565f6d76255a0.boutiques",
    name="cifti-gradient",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiGradientLeftSurface:
    """
    specify the left surface to use.
    """
    surface: InputPathType
    """the left surface file"""
    opt_left_corrected_areas_area_metric: InputPathType | None = None
    """vertex areas to use instead of computing them from the left surface: the
    corrected vertex areas, as a metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_left_corrected_areas_area_metric is not None:
            cargs.extend([
                "-left-corrected-areas",
                execution.input_file(self.opt_left_corrected_areas_area_metric)
            ])
        return cargs


@dataclasses.dataclass
class CiftiGradientRightSurface:
    """
    specify the right surface to use.
    """
    surface: InputPathType
    """the right surface file"""
    opt_right_corrected_areas_area_metric: InputPathType | None = None
    """vertex areas to use instead of computing them from the right surface: the
    corrected vertex areas, as a metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_right_corrected_areas_area_metric is not None:
            cargs.extend([
                "-right-corrected-areas",
                execution.input_file(self.opt_right_corrected_areas_area_metric)
            ])
        return cargs


@dataclasses.dataclass
class CiftiGradientCerebellumSurface:
    """
    specify the cerebellum surface to use.
    """
    surface: InputPathType
    """the cerebellum surface file"""
    opt_cerebellum_corrected_areas_area_metric: InputPathType | None = None
    """vertex areas to use instead of computing them from the cerebellum
    surface: the corrected vertex areas, as a metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_cerebellum_corrected_areas_area_metric is not None:
            cargs.extend([
                "-cerebellum-corrected-areas",
                execution.input_file(self.opt_cerebellum_corrected_areas_area_metric)
            ])
        return cargs


class CiftiGradientOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_gradient(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti"""
    vectors_out: OutputPathType
    """the vectors, as a dscalar file"""


def cifti_gradient(
    cifti: InputPathType,
    direction: str,
    cifti_out: str,
    vectors_out: str,
    left_surface: CiftiGradientLeftSurface | None = None,
    right_surface: CiftiGradientRightSurface | None = None,
    cerebellum_surface: CiftiGradientCerebellumSurface | None = None,
    opt_surface_presmooth_surface_kernel: float | None = None,
    opt_volume_presmooth_volume_kernel: float | None = None,
    opt_presmooth_fwhm: bool = False,
    opt_average_output: bool = False,
    opt_vectors: bool = False,
    runner: Runner | None = None,
) -> CiftiGradientOutputs:
    """
    Take gradient of a cifti file.
    
    Performs gradient calculation on each component of the cifti file, and
    optionally averages the resulting gradients. The -vectors and
    -average-output options may not be used together. You must specify a surface
    for each surface structure in the cifti file. The COLUMN direction should be
    faster, and is the direction that works on dtseries. For dconn, you probably
    want ROW, unless you are using -average-output.
    
    Author: Washington University School of Medicin
    
    Args:
        cifti: the input cifti.
        direction: which dimension to take the gradient along, ROW or COLUMN.
        cifti_out: the output cifti.
        vectors_out: the vectors, as a dscalar file.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        opt_surface_presmooth_surface_kernel: smooth on the surface before\
            computing the gradient: the size of the gaussian surface smoothing\
            kernel in mm, as sigma by default.
        opt_volume_presmooth_volume_kernel: smooth on the surface before\
            computing the gradient: the size of the gaussian volume smoothing\
            kernel in mm, as sigma by default.
        opt_presmooth_fwhm: smoothing kernel sizes are FWHM, not sigma.
        opt_average_output: output the average of the gradient magnitude maps\
            instead of each gradient map separately.
        opt_vectors: output gradient vectors.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiGradientOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_GRADIENT_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-gradient")
    cargs.append(execution.input_file(cifti))
    cargs.append(direction)
    cargs.append(cifti_out)
    if left_surface is not None:
        cargs.extend(left_surface.run(execution))
    if right_surface is not None:
        cargs.extend(right_surface.run(execution))
    if cerebellum_surface is not None:
        cargs.extend(cerebellum_surface.run(execution))
    if opt_surface_presmooth_surface_kernel is not None:
        cargs.extend([
            "-surface-presmooth",
            str(opt_surface_presmooth_surface_kernel)
        ])
    if opt_volume_presmooth_volume_kernel is not None:
        cargs.extend([
            "-volume-presmooth",
            str(opt_volume_presmooth_volume_kernel)
        ])
    if opt_presmooth_fwhm:
        cargs.append("-presmooth-fwhm")
    if opt_average_output:
        cargs.append("-average-output")
    if opt_vectors:
        cargs.append("-vectors")
    cargs.append(vectors_out)
    ret = CiftiGradientOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
        vectors_out=execution.output_file(vectors_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_GRADIENT_METADATA",
    "CiftiGradientCerebellumSurface",
    "CiftiGradientLeftSurface",
    "CiftiGradientOutputs",
    "CiftiGradientRightSurface",
    "cifti_gradient",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_RANKIZER_METADATA = Metadata(
    id="1526787c6fe081182b67655916ab181312ed5958.boutiques",
    name="3dRankizer",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dRankizerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_rankizer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Output float-format dataset containing ranked voxel values"""


def v_3d_rankizer(
    dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dRankizerOutputs:
    """
    Tool to rank each voxel as sorted into increasing value. Ties get the average
    rank.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dRankizer.html
    
    Args:
        dataset: Input MRI dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dRankizerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_RANKIZER_METADATA)
    cargs = []
    cargs.append("3dRankizer")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(dataset))
    ret = V3dRankizerOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file("[PPP]+tlrc.HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dRankizerOutputs",
    "V_3D_RANKIZER_METADATA",
    "v_3d_rankizer",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

APPLY_WARP_METADATA = Metadata(
    id="630ba2cd799dc0d962b6facceab132dec39ae724.boutiques",
    name="apply_warp",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ApplyWarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `apply_warp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file_outfile: OutputPathType | None
    """Warped output file."""


def apply_warp(
    in_file: InputPathType,
    ref_file: InputPathType,
    interp: typing.Literal["nn", "trilinear", "sinc", "spline"] | None = None,
    out_file: InputPathType | None = None,
    relwarp: bool = False,
    abswarp: bool = False,
    datatype: typing.Literal["char", "short", "int", "float", "double"] | None = None,
    field_file: InputPathType | None = None,
    mask_file: InputPathType | None = None,
    output_type: typing.Literal["NIFTI", "NIFTI_PAIR", "NIFTI_GZ", "NIFTI_PAIR_GZ"] | None = None,
    postmat: InputPathType | None = None,
    premat: InputPathType | None = None,
    superlevel_2: int | None = None,
    supersample: bool = False,
    runner: Runner | None = None,
) -> ApplyWarpOutputs:
    """
    Apply warps estimated by FNIRT (or some other software) to some image.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    Args:
        in_file: Image to be warped.
        ref_file: Reference image.
        interp: 'nn' or 'trilinear' or 'sinc' or 'spline'. Interpolation\
            method.
        out_file: Output filename.
        relwarp: Treat warp field as relative: x' = x + w(x).
        abswarp: Treat warp field as absolute: x' = w(x).
        datatype: 'char' or 'short' or 'int' or 'float' or 'double'. Force\
            output data type [char short int float double].
        field_file: File containing warp field.
        mask_file: Filename for mask image (in reference space).
        output_type: 'nifti' or 'nifti_pair' or 'nifti_gz' or 'nifti_pair_gz'.\
            Fsl output type.
        postmat: Filename for post-transform (affine matrix).
        premat: Filename for pre-transform (affine matrix).
        superlevel_2: 'a' or an integer. Level of intermediary supersampling, a\
            for 'automatic' or integer level. default = 2.
        supersample: Intermediary supersampling of output, default is off.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ApplyWarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(APPLY_WARP_METADATA)
    cargs = []
    cargs.append("applywarp")
    if interp is not None:
        cargs.append("--interp=" + interp)
    cargs.append("--in=" + execution.input_file(in_file))
    cargs.append("--ref=" + execution.input_file(ref_file))
    if out_file is not None:
        cargs.append("--out=" + execution.input_file(out_file))
    if relwarp:
        cargs.append("--rel")
    if abswarp:
        cargs.append("--abs")
    if datatype is not None:
        cargs.append("--datatype=" + datatype)
    if field_file is not None:
        cargs.append("--warp=" + execution.input_file(field_file))
    if mask_file is not None:
        cargs.append("--mask=" + execution.input_file(mask_file))
    if output_type is not None:
        cargs.append(output_type)
    if postmat is not None:
        cargs.append("--postmat=" + execution.input_file(postmat))
    if premat is not None:
        cargs.append("--premat=" + execution.input_file(premat))
    if superlevel_2 is not None:
        cargs.append("--superlevel=" + str(superlevel_2))
    if supersample:
        cargs.append("--super")
    ret = ApplyWarpOutputs(
        root=execution.output_file("."),
        out_file_outfile=execution.output_file(pathlib.Path(out_file).name) if (out_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "APPLY_WARP_METADATA",
    "ApplyWarpOutputs",
    "apply_warp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SLICE_METADATA = Metadata(
    id="0f7440fb6cdaef38819dd7bdf5e47704f5d4f5f2.boutiques",
    name="slice",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SliceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `slice_(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_files: OutputPathType
    """No description provided."""


def slice_(
    in_file: InputPathType,
    out_base_name: str | None = None,
    output_type: typing.Literal["NIFTI", "NIFTI_PAIR", "NIFTI_GZ", "NIFTI_PAIR_GZ"] | None = None,
    runner: Runner | None = None,
) -> SliceOutputs:
    """
    Use fslslice to split a 3D file into lots of 2D files (along z-axis).
    
    Author: Nipype (interface)
    
    Args:
        in_file: Input filename.
        out_base_name: Outputs prefix.
        output_type: 'nifti' or 'nifti_pair' or 'nifti_gz' or 'nifti_pair_gz'.\
            Fsl output type.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SliceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SLICE_METADATA)
    cargs = []
    cargs.append("Slice")
    cargs.append(execution.input_file(in_file))
    if out_base_name is not None:
        cargs.append(out_base_name)
    if output_type is not None:
        cargs.append(output_type)
    ret = SliceOutputs(
        root=execution.output_file("."),
        out_files=execution.output_file("out_files"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SLICE_METADATA",
    "SliceOutputs",
    "slice_",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ROTCOM_METADATA = Metadata(
    id="82b02b85ea72d222e3f150bd7d5de9edb4b1ec75.boutiques",
    name="rotcom",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class RotcomOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rotcom(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stdout: OutputPathType
    """The 4x3 transformation matrix+vector output"""


def rotcom(
    rotate_ashift: str,
    dataset: InputPathType | None = None,
    runner: Runner | None = None,
) -> RotcomOutputs:
    """
    Prints to stdout the 4x3 transformation matrix+vector that would be applied by
    3drotate to the given dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/rotcom.html
    
    Args:
        rotate_ashift: Combination of rotate and ashift options in a single\
            quoted string (e.g., '-rotate 10I 0R 0A -ashift 5S 0 0').
        dataset: Input dataset for determining coordinate order.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RotcomOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ROTCOM_METADATA)
    cargs = []
    cargs.append("rotcom")
    cargs.append(rotate_ashift)
    if dataset is not None:
        cargs.append(execution.input_file(dataset))
    ret = RotcomOutputs(
        root=execution.output_file("."),
        stdout=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ROTCOM_METADATA",
    "RotcomOutputs",
    "rotcom",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_CLOSEST_VERTEX_METADATA = Metadata(
    id="715f1128956c8b8db48c116f7ba91ed896751881.boutiques",
    name="surface-closest-vertex",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceClosestVertexOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_closest_vertex(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surface_closest_vertex(
    surface: InputPathType,
    coord_list_file: str,
    vertex_list_out: str,
    runner: Runner | None = None,
) -> SurfaceClosestVertexOutputs:
    """
    Find closest surface vertex to coordinates.
    
    For each coordinate XYZ triple, find the closest vertex in the surface, and
    output its vertex number into a text file. The input file should only use
    whitespace to separate coordinates (spaces, newlines, tabs), for instance:
    
    20 30 25
    30 -20 10.
    
    Author: Washington University School of Medicin
    
    Args:
        surface: the surface to use.
        coord_list_file: text file with coordinates.
        vertex_list_out: output - the output text file with vertex numbers.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceClosestVertexOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_CLOSEST_VERTEX_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-closest-vertex")
    cargs.append(execution.input_file(surface))
    cargs.append(coord_list_file)
    cargs.append(vertex_list_out)
    ret = SurfaceClosestVertexOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_CLOSEST_VERTEX_METADATA",
    "SurfaceClosestVertexOutputs",
    "surface_closest_vertex",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_PARCEL_MAPPING_TO_LABEL_METADATA = Metadata(
    id="32140024ca7b96c0d11ae8c7eb35cc233f5f818a.boutiques",
    name="cifti-parcel-mapping-to-label",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class CiftiParcelMappingToLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_parcel_mapping_to_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dlabel_out: OutputPathType
    """the output dense label file"""


def cifti_parcel_mapping_to_label(
    cifti_in: InputPathType,
    direction: str,
    template_cifti: InputPathType,
    dlabel_out: str,
    runner: Runner | None = None,
) -> CiftiParcelMappingToLabelOutputs:
    """
    Create dlabel from parcellated file.
    
    This command will output a dlabel file, useful for doing the same
    parcellation to another dense file.
    
    For ptseries, pscalar, plabel, pconn, and pdconn, using COLUMN for
    <direction> will work.
    
    Author: Washington University School of Medicin
    
    Args:
        cifti_in: the input parcellated file.
        direction: which dimension to take the parcel map from, ROW or COLUMN.
        template_cifti: a cifti file with the desired dense mapping along\
            column.
        dlabel_out: the output dense label file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiParcelMappingToLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_PARCEL_MAPPING_TO_LABEL_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-parcel-mapping-to-label")
    cargs.append(execution.input_file(cifti_in))
    cargs.append(direction)
    cargs.append(execution.input_file(template_cifti))
    cargs.append(dlabel_out)
    ret = CiftiParcelMappingToLabelOutputs(
        root=execution.output_file("."),
        dlabel_out=execution.output_file(dlabel_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_PARCEL_MAPPING_TO_LABEL_METADATA",
    "CiftiParcelMappingToLabelOutputs",
    "cifti_parcel_mapping_to_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MVM_VALIDATOR_METADATA = Metadata(
    id="363acd1c4d041e492d2ad96e8d901ff72270d361.boutiques",
    name="3dMVM_validator",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMvmValidatorOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_mvm_validator(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    temp_folder: OutputPathType
    """Temporary folder created during the shiny app session."""


def v_3d_mvm_validator(
    datatable: InputPathType,
    shinyfolder: str | None = None,
    runner: Runner | None = None,
) -> V3dMvmValidatorOutputs:
    """
    Launch the 3dMVM model validation shiny app in a web browser.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dMVM_validator.html
    
    Args:
        datatable: A file containing a data table formatted like the 3dMVM\
            "-dataTable".
        shinyfolder: Use a custom shiny folder (for testing purposes).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMvmValidatorOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MVM_VALIDATOR_METADATA)
    cargs = []
    cargs.append("3dMVM_validator")
    cargs.append(execution.input_file(datatable))
    if shinyfolder is not None:
        cargs.extend([
            "-ShinyFolder",
            shinyfolder
        ])
    ret = V3dMvmValidatorOutputs(
        root=execution.output_file("."),
        temp_folder=execution.output_file("__*_3dMVM_validator_temp_delete"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMvmValidatorOutputs",
    "V_3D_MVM_VALIDATOR_METADATA",
    "v_3d_mvm_validator",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMG2IMGCOORD_METADATA = Metadata(
    id="e2592d4318b2febffcef765126849541c054b328.boutiques",
    name="img2imgcoord",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Img2imgcoordOutputs(typing.NamedTuple):
    """
    Output object returned when calling `img2imgcoord(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def img2imgcoord(
    coordinates_file: str,
    runner: Runner | None = None,
) -> Img2imgcoordOutputs:
    """
    Tool for transforming coordinates between images.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FLIRT
    
    Args:
        coordinates_file: Filename containing coordinates.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Img2imgcoordOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMG2IMGCOORD_METADATA)
    cargs = []
    cargs.append("img2imgcoord")
    cargs.append("[OPTIONS]")
    cargs.append(coordinates_file)
    ret = Img2imgcoordOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMG2IMGCOORD_METADATA",
    "Img2imgcoordOutputs",
    "img2imgcoord",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EDDY_METADATA = Metadata(
    id="f2dd23d70ac60a5fd678ef452b8ec840c1f43303.boutiques",
    name="eddy",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class EddyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `eddy(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out: OutputPathType
    """Output file containing the corrected images"""


def eddy(
    imain: InputPathType,
    mask: InputPathType,
    index: InputPathType,
    acqp: InputPathType,
    bvecs: InputPathType,
    bvals: InputPathType,
    implementation: typing.Literal["", "_openmp", "_cuda", "_cuda10.2", "_cuda9.1", "_cuda8.0"] = "",
    out: str = "eddy_corrected",
    mb: float | None = None,
    mb_offs: float | None = None,
    slspec: InputPathType | None = None,
    json_: InputPathType | None = None,
    mporder: float | None = None,
    s2v_lambda: float | None = None,
    topup_: InputPathType | None = None,
    field: InputPathType | None = None,
    field_mat: InputPathType | None = None,
    flm: typing.Literal["movement", "linear", "quadratic", "cubic"] | None = None,
    slm: typing.Literal["none", "linear", "quadratic"] | None = None,
    fwhm: float | None = None,
    niter: float | None = None,
    s2v_niter: float | None = None,
    cnr_maps: bool = False,
    residuals: bool = False,
    fep: bool = False,
    interp: typing.Literal["spline", "trilinear"] | None = None,
    s2v_interp: typing.Literal["spline", "trilinear"] | None = None,
    resamp: typing.Literal["jac", "lsr"] | None = None,
    nvoxhp: float | None = None,
    initrand: float | None = None,
    ff: float | None = None,
    repol: bool = False,
    ol_nstd: float | None = None,
    ol_nvox: float | None = None,
    ol_type: typing.Literal["sw", "gw", "both"] | None = None,
    ol_pos: bool = False,
    ol_sqr: bool = False,
    estimate_move_by_susceptibility: bool = False,
    mbs_niter: float | None = None,
    mbs_lambda: float | None = None,
    mbs_ksp: float | None = None,
    dont_sep_offs_move: bool = False,
    dont_peas: bool = False,
    data_is_shelled: bool = False,
    verbose: bool = False,
    runner: Runner | None = None,
) -> EddyOutputs:
    """
    A tool for correcting eddy currents and movements in diffusion data.
    
    Author: Jesper Andersson (University of Oxford)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/eddy
    
    Args:
        imain: File containing all the images to estimate distortions for.
        mask: Mask to indicate brain.
        index: File containing indices for all volumes in --imain into --acqp\
            and --topup.
        acqp: File containing acquisition parameters.
        bvecs: File containing the b-vectors for all volumes in --imain.
        bvals: File containing the b-values for all volumes in --imain.
        implementation: Choose the implementation to use.
        out: Basename for output.
        mb: Multi-band factor.
        mb_offs: Multi-band offset (-1 if bottom slice removed, 1 if top slice\
            removed).
        slspec: Name of text file completely specifying slice/group acuistion.\
            N.B. --slspec and --json are mutually exclusive.
        json_: Name of .json text file with information about slice timing.\
            N.B. --json and --slspec are mutually exclusive.
        mporder: Order of slice-to-vol movement model (default 0, i.e.\
            vol-to-vol.
        s2v_lambda: Regularisation weight for slice-to-vol movement. (default\
            1, reasonable range 1--10).
        topup_: Base name for output files from topup.
        field: Name of file with susceptibility field (in Hz).
        field_mat: Name of rigid body transform for susceptibility field.
        flm: First level EC model (movement/linear/quadratic/cubic, default\
            quadratic).
        slm: Second level EC model (none/linear/quadratic, default none).
        fwhm: FWHM for conditioning filter when estimating the parameters\
            (default 0).
        niter: Number of iterations (default 5).
        s2v_niter: Number of iterations for slice-to-vol (default 5).
        cnr_maps: Write shell-wise cnr-maps (default false).
        residuals: Write residuals (between GP and observations), (default\
            false).
        fep: Fill empty planes in x- or y-directions (default false).
        interp: Interpolation model for estimation step (spline/trilinear,\
            default spline).
        s2v_interp: Slice-to-vol interpolation model for estimation step\
            (spline/trilinear, default trilinear).
        resamp: Final resampling method (jac/lsr, default jac).
        nvoxhp: # of voxels used to estimate the hyperparameters (default 1000).
        initrand: Seeds rand for when selecting voxels (default 0=no seeding).
        ff: Fudge factor for hyperparameter error variance (default 10.0).
        repol: Detect and replace outlier slices (default false)).
        ol_nstd: Number of std off to qualify as outlier (default 4).
        ol_nvox: Min # of voxels in a slice for inclusion in outlier detection\
            (default 250).
        ol_type: Type of outliers, slicewise (sw), groupwise (gw) or both\
            (both). (default sw).
        ol_pos: Consider both positive and negative outliers if set (default\
            false).
        ol_sqr: Consider outliers among sums-of-squared differences if set\
            (default false).
        estimate_move_by_susceptibility: Estimate how susceptibility field\
            changes with subject movement (default false).
        mbs_niter: Number of iterations for MBS estimation (default 10).
        mbs_lambda: Weighting of regularisation for MBS estimation (default 10).
        mbs_ksp: Knot-spacing for MBS field estimation (default 10mm).
        dont_sep_offs_move: Do NOT attempt to separate field offset from\
            subject movement (default false).
        dont_peas: Do NOT perform a post-eddy alignment of shells (default\
            false).
        data_is_shelled: Assume, don't check, that data is shelled (default\
            false).
        verbose: switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EddyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EDDY_METADATA)
    cargs = []
    cargs.append("eddy" + implementation)
    cargs.append("--imain=" + execution.input_file(imain))
    cargs.append("--mask=" + execution.input_file(mask))
    cargs.append("--index=" + execution.input_file(index))
    cargs.append("--acqp=" + execution.input_file(acqp))
    cargs.append("--bvecs=" + execution.input_file(bvecs))
    cargs.append("--bvals=" + execution.input_file(bvals))
    cargs.append("--out=" + out)
    if mb is not None:
        cargs.append("--mb=" + str(mb))
    if mb_offs is not None:
        cargs.append("--mb_offs=" + str(mb_offs))
    if slspec is not None:
        cargs.append("--slspec=" + execution.input_file(slspec))
    if json_ is not None:
        cargs.append("--json=" + execution.input_file(json_))
    if mporder is not None:
        cargs.append("--mporder=" + str(mporder))
    if s2v_lambda is not None:
        cargs.append("--s2v_lambda=" + str(s2v_lambda))
    if topup_ is not None:
        cargs.append("--topup=" + execution.input_file(topup_, resolve_parent=True))
    if field is not None:
        cargs.append("--field=" + execution.input_file(field))
    if field_mat is not None:
        cargs.append("--field_mat=" + execution.input_file(field_mat))
    if flm is not None:
        cargs.append("--flm=" + flm)
    if slm is not None:
        cargs.append("--slm=" + slm)
    if fwhm is not None:
        cargs.append("--fwhm=" + str(fwhm))
    if niter is not None:
        cargs.append("--niter=" + str(niter))
    if s2v_niter is not None:
        cargs.append("--s2v_niter=" + str(s2v_niter))
    if cnr_maps:
        cargs.append("--cnr_maps")
    if residuals:
        cargs.append("--residuals")
    if fep:
        cargs.append("--fep")
    if interp is not None:
        cargs.append("--interp=" + interp)
    if s2v_interp is not None:
        cargs.append("--s2v_interp=" + s2v_interp)
    if resamp is not None:
        cargs.append("--resamp=" + resamp)
    if nvoxhp is not None:
        cargs.append("--nvoxhp=" + str(nvoxhp))
    if initrand is not None:
        cargs.append("--initrand=" + str(initrand))
    if ff is not None:
        cargs.append("--ff=" + str(ff))
    if repol:
        cargs.append("--repol")
    if ol_nstd is not None:
        cargs.append("--ol_nstd=" + str(ol_nstd))
    if ol_nvox is not None:
        cargs.append("--ol_nvox=" + str(ol_nvox))
    if ol_type is not None:
        cargs.append("--ol_type=" + ol_type)
    if ol_pos:
        cargs.append("--ol_pos")
    if ol_sqr:
        cargs.append("--ol_sqr")
    if estimate_move_by_susceptibility:
        cargs.append("--estimate_move_by_susceptibility")
    if mbs_niter is not None:
        cargs.append("--mbs_niter=" + str(mbs_niter))
    if mbs_lambda is not None:
        cargs.append("--mbs_lambda=" + str(mbs_lambda))
    if mbs_ksp is not None:
        cargs.append("--mbs_ksp=" + str(mbs_ksp))
    if dont_sep_offs_move:
        cargs.append("--dont_sep_offs_move")
    if dont_peas:
        cargs.append("--dont_peas")
    if data_is_shelled:
        cargs.append("--data_is_shelled")
    if verbose:
        cargs.append("--verbose")
    ret = EddyOutputs(
        root=execution.output_file("."),
        out=execution.output_file(out + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EDDY_METADATA",
    "EddyOutputs",
    "eddy",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MEDIAN_FILTER_METADATA = Metadata(
    id="fd3886bd6ff2fda6a99026dc98c4ccdf74daec27.boutiques",
    name="3dMedianFilter",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMedianFilterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_median_filter(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_brik: OutputPathType | None
    """Output dataset is stored in float format."""
    output_head: OutputPathType | None
    """Output dataset header file."""


def v_3d_median_filter(
    dataset: InputPathType,
    irad: float | None = None,
    iter_: float | None = None,
    verbose: bool = False,
    prefix: str | None = None,
    automask: bool = False,
    runner: Runner | None = None,
) -> V3dMedianFilterOutputs:
    """
    Computes the median in a spherical neighborhood around each point in the input
    to produce the output.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dMedianFilter.html
    
    Args:
        dataset: Input dataset.
        irad: Radius in voxels of spherical regions.
        iter_: Iterate 'n' times [default=1].
        verbose: Be verbose during run.
        prefix: Use 'pp' for prefix of output dataset.
        automask: Create a mask (a la 3dAutomask).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMedianFilterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MEDIAN_FILTER_METADATA)
    cargs = []
    cargs.append("3dMedianFilter")
    if irad is not None:
        cargs.extend([
            "-irad",
            str(irad)
        ])
    if iter_ is not None:
        cargs.extend([
            "-iter",
            str(iter_)
        ])
    if verbose:
        cargs.append("-verb")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if automask:
        cargs.append("-automask")
    cargs.append(execution.input_file(dataset))
    ret = V3dMedianFilterOutputs(
        root=execution.output_file("."),
        output_brik=execution.output_file(prefix + "+tlrc.BRIK") if (prefix is not None) else None,
        output_head=execution.output_file(prefix + "+tlrc.HEAD") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMedianFilterOutputs",
    "V_3D_MEDIAN_FILTER_METADATA",
    "v_3d_median_filter",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TO3D_METADATA = Metadata(
    id="e0b1a8079bd8c845d68df128a96c8155a51e0e19.boutiques",
    name="to3d",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class To3dOutputs(typing.NamedTuple):
    """
    Output object returned when calling `to3d(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    headfile: OutputPathType | None
    """Output AFNI HEAD file"""
    brikfile: OutputPathType | None
    """Output AFNI BRIK file"""
    outfile_outliers: OutputPathType | None
    """Outlier count file"""


def to3d(
    input_files: list[InputPathType],
    type_: typing.Literal["spgr", "fse", "epan", "anat", "ct", "spct", "pet", "mra", "bmap", "diff", "omri", "abuc", "fim", "fith", "fico", "fitt", "fift", "fizt", "fict", "fibt", "fibn", "figt", "fipt", "fbuc"] | None = None,
    statpar: list[float] | None = None,
    prefix: str | None = None,
    session: str | None = None,
    geomparent: InputPathType | None = None,
    anatparent: InputPathType | None = None,
    nosave_flag: bool = False,
    nowritebrik_flag: bool = False,
    view: typing.Literal["orig", "acpc", "tlrc"] | None = None,
    time_zt: list[str] | None = None,
    time_tz: list[str] | None = None,
    tr_units: typing.Literal["ms", "msec", "s", "sec", "Hz", "Hertz"] | None = None,
    torg: float | None = None,
    x_fov: str | None = None,
    y_fov: str | None = None,
    z_fov: str | None = None,
    x_slab: str | None = None,
    y_slab: str | None = None,
    z_slab: str | None = None,
    zorigin: float | None = None,
    data_type: typing.Literal["short", "float", "byte", "complex"] | None = None,
    global_scaling_factor: float | None = None,
    nofloatscan_flag: bool = False,
    in1_flag: bool = False,
    orient: str | None = None,
    skip_outliers_flag: bool = False,
    text_outliers_flag: bool = False,
    save_outliers: str | None = None,
    assume_dicom_mosaic_flag: bool = False,
    oblique_origin_flag: bool = False,
    reverse_list_flag: bool = False,
    use_last_elem_flag: bool = False,
    use_old_mosaic_code_flag: bool = False,
    ushort2float_flag: bool = False,
    verbose_flag: bool = False,
    gamma: float | None = None,
    ncolors: float | None = None,
    xtwarns_flag: bool = False,
    quit_on_err_flag: bool = False,
    runner: Runner | None = None,
) -> To3dOutputs:
    """
    Creates 3D datasets for use with AFNI from 2D image files.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/to3d.html
    
    Args:
        input_files: Input 2D image files.
        type_: Declare images to contain data of a given type.
        statpar: Supply auxiliary statistical parameters.
        prefix: Prefix of the output 3D dataset.
        session: Session directory for output 3D dataset.
        geomparent: Read geometry data from dataset file.
        anatparent: Take anatomy parent from dataset file.
        nosave_flag: Suppress autosave of 3D dataset.
        nowritebrik_flag: Suppress saving of the BRIK file.
        view: Set the dataset's viewing coordinates.
        time_zt: Specify time dependent dataset (z-axis first, then t-axis).
        time_tz: Specify time dependent dataset (t-axis first, then z-axis).
        tr_units: Specify TR units.
        torg: Set time origin of dataset.
        x_fov: Specify size and orientation of the x-axis extent.
        y_fov: Specify size and orientation of the y-axis extent.
        z_fov: Specify size and orientation of the z-axis extent.
        x_slab: Specify x-axis slab.
        y_slab: Specify y-axis slab.
        z_slab: Specify z-axis slab.
        zorigin: Set the center of the first slice offset in z-axis.
        data_type: Set voxel data to be stored as given data type.
        global_scaling_factor: Global scaling factor.
        nofloatscan_flag: Do not scan for illegal floating point values.
        in1_flag: Read and process images one slice at a time.
        orient: Set the orientation of the 3D volumes.
        skip_outliers_flag: Skip the outlier check for 3D+time datasets.
        text_outliers_flag: Only print out the outlier check results in text\
            form.
        save_outliers: Save the outliers count into a 1D file.
        assume_dicom_mosaic_flag: Assume any Siemens DICOM file is a potential\
            MOSAIC image.
        oblique_origin_flag: Assume origin and orientation from oblique\
            transformation matrix.
        reverse_list_flag: Reverse the input file list.
        use_last_elem_flag: Search DICOM images for the last occurrence of each\
            element.
        use_old_mosaic_code_flag: Do not use the Dec 2010 updates to Siemens\
            mosaic code.
        ushort2float_flag: Convert input shorts to float and add 2^16 to any\
            negatives.
        verbose_flag: Show debugging information for reading DICOM files.
        gamma: Gamma correction factor for the monitor.
        ncolors: Number of gray levels for the image displays.
        xtwarns_flag: Turn on display of Xt warning messages.
        quit_on_err_flag: Do not launch interactive to3d mode if input has\
            error.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `To3dOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TO3D_METADATA)
    cargs = []
    cargs.append("to3d")
    cargs.extend([execution.input_file(f) for f in input_files])
    if type_ is not None:
        cargs.extend([
            "-type",
            type_
        ])
    if statpar is not None:
        cargs.extend([
            "-statpar",
            *map(str, statpar)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if session is not None:
        cargs.extend([
            "-session",
            session
        ])
    if geomparent is not None:
        cargs.extend([
            "-geomparent",
            execution.input_file(geomparent)
        ])
    if anatparent is not None:
        cargs.extend([
            "-anatparent",
            execution.input_file(anatparent)
        ])
    if nosave_flag:
        cargs.append("-nosave")
    if nowritebrik_flag:
        cargs.append("-nowritebrik")
    if view is not None:
        cargs.extend([
            "-view",
            view
        ])
    if time_zt is not None:
        cargs.extend([
            "-time:zt",
            *time_zt
        ])
    if time_tz is not None:
        cargs.extend([
            "-time:tz",
            *time_tz
        ])
    if tr_units is not None:
        cargs.extend([
            "-t",
            tr_units
        ])
    if torg is not None:
        cargs.extend([
            "-Torg",
            str(torg)
        ])
    if x_fov is not None:
        cargs.extend([
            "-xFOV",
            x_fov
        ])
    if y_fov is not None:
        cargs.extend([
            "-yFOV",
            y_fov
        ])
    if z_fov is not None:
        cargs.extend([
            "-zFOV",
            z_fov
        ])
    if x_slab is not None:
        cargs.extend([
            "-xSLAB",
            x_slab
        ])
    if y_slab is not None:
        cargs.extend([
            "-ySLAB",
            y_slab
        ])
    if z_slab is not None:
        cargs.extend([
            "-zSLAB",
            z_slab
        ])
    if zorigin is not None:
        cargs.extend([
            "-zorigin",
            str(zorigin)
        ])
    if data_type is not None:
        cargs.extend([
            "-datum",
            data_type
        ])
    if global_scaling_factor is not None:
        cargs.extend([
            "-gsfac",
            str(global_scaling_factor)
        ])
    if nofloatscan_flag:
        cargs.append("-nofloatscan")
    if in1_flag:
        cargs.append("-in:1")
    if orient is not None:
        cargs.extend([
            "-orient",
            orient
        ])
    if skip_outliers_flag:
        cargs.append("-skip_outliers")
    if text_outliers_flag:
        cargs.append("-text_outliers")
    if save_outliers is not None:
        cargs.extend([
            "-save_outliers",
            save_outliers
        ])
    if assume_dicom_mosaic_flag:
        cargs.append("-assume_dicom_mosaic")
    if oblique_origin_flag:
        cargs.append("-oblique_origin")
    if reverse_list_flag:
        cargs.append("-reverse_list")
    if use_last_elem_flag:
        cargs.append("-use_last_elem")
    if use_old_mosaic_code_flag:
        cargs.append("-use_old_mosaic_code")
    if ushort2float_flag:
        cargs.append("-ushort2float")
    if verbose_flag:
        cargs.append("-verb")
    if gamma is not None:
        cargs.extend([
            "-gamma",
            str(gamma)
        ])
    if ncolors is not None:
        cargs.extend([
            "-ncolors",
            str(ncolors)
        ])
    if xtwarns_flag:
        cargs.append("-xtwarns")
    if quit_on_err_flag:
        cargs.append("-quit_on_err")
    ret = To3dOutputs(
        root=execution.output_file("."),
        headfile=execution.output_file(prefix + ".HEAD") if (prefix is not None) else None,
        brikfile=execution.output_file(prefix + ".BRIK") if (prefix is not None) else None,
        outfile_outliers=execution.output_file(save_outliers) if (save_outliers is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TO3D_METADATA",
    "To3dOutputs",
    "to3d",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SLICESDIR_METADATA = Metadata(
    id="d0d33e48a4c39100315cb0c896f14f3ba8c38489.boutiques",
    name="slicesdir",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SlicesdirOutputs(typing.NamedTuple):
    """
    Output object returned when calling `slicesdir(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def slicesdir(
    filelist: list[str],
    flag_filelist: bool = False,
    outline_image: InputPathType | None = None,
    edge_threshold: float | None = None,
    slice_option: bool = False,
    runner: Runner | None = None,
) -> SlicesdirOutputs:
    """
    slicesdir generates a directory containing orthogonal slices through a set of
    images.
    
    Author: FMRIB Centre, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils#SLICESDIR
    
    Args:
        filelist: List of image files to process.
        flag_filelist: Filelist contains pairs of images (underlying and\
            red-outline images).
        outline_image: Use the specified image as the red-outline image on top\
            of all images in the file list.
        edge_threshold: Use specified threshold for edges. If >0, use this\
            proportion of max-min; if <0, use the absolute value.
        slice_option: Output every second axial slice instead of 9 ortho slices.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SlicesdirOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SLICESDIR_METADATA)
    cargs = []
    cargs.append("slicesdir")
    if flag_filelist:
        cargs.append("-o")
    if outline_image is not None:
        cargs.extend([
            "-p",
            execution.input_file(outline_image)
        ])
    if edge_threshold is not None:
        cargs.extend([
            "-e",
            str(edge_threshold)
        ])
    if slice_option:
        cargs.append("-S")
    cargs.extend(filelist)
    ret = SlicesdirOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SLICESDIR_METADATA",
    "SlicesdirOutputs",
    "slicesdir",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FOCI_RESAMPLE_METADATA = Metadata(
    id="a44a1e656dac192f3d9fc53cc05d57a91f7c697d.boutiques",
    name="foci-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class FociResampleLeftSurfaces:
    """
    the left surfaces for resampling.
    """
    current_surf: InputPathType
    """the surface the foci are currently projected on"""
    new_surf: InputPathType
    """the surface to project the foci onto"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-surfaces")
        cargs.append(execution.input_file(self.current_surf))
        cargs.append(execution.input_file(self.new_surf))
        return cargs


@dataclasses.dataclass
class FociResampleRightSurfaces:
    """
    the right surfaces for resampling.
    """
    current_surf: InputPathType
    """the surface the foci are currently projected on"""
    new_surf: InputPathType
    """the surface to project the foci onto"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-surfaces")
        cargs.append(execution.input_file(self.current_surf))
        cargs.append(execution.input_file(self.new_surf))
        return cargs


@dataclasses.dataclass
class FociResampleCerebellumSurfaces:
    """
    the cerebellum surfaces for resampling.
    """
    current_surf: InputPathType
    """the surface the foci are currently projected on"""
    new_surf: InputPathType
    """the surface to project the foci onto"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-surfaces")
        cargs.append(execution.input_file(self.current_surf))
        cargs.append(execution.input_file(self.new_surf))
        return cargs


class FociResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `foci_resample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    foci_out: OutputPathType
    """the output foci file"""


def foci_resample(
    foci_in: InputPathType,
    foci_out: str,
    left_surfaces: FociResampleLeftSurfaces | None = None,
    right_surfaces: FociResampleRightSurfaces | None = None,
    cerebellum_surfaces: FociResampleCerebellumSurfaces | None = None,
    opt_discard_distance_from_surface: bool = False,
    opt_restore_xyz: bool = False,
    runner: Runner | None = None,
) -> FociResampleOutputs:
    """
    Project foci to a different surface.
    
    Unprojects foci from the <current-surf> for the structure, then projects
    them to <new-surf>. If the foci have meaningful distances above or below the
    surface, use anatomical surfaces. If the foci should be on the surface, use
    registered spheres and the options -discard-distance-from-surface and
    -restore-xyz.
    
    Author: Washington University School of Medicin
    
    Args:
        foci_in: the input foci file.
        foci_out: the output foci file.
        left_surfaces: the left surfaces for resampling.
        right_surfaces: the right surfaces for resampling.
        cerebellum_surfaces: the cerebellum surfaces for resampling.
        opt_discard_distance_from_surface: ignore the distance the foci are\
            above or below the current surface.
        opt_restore_xyz: put the original xyz coordinates into the foci, rather\
            than the coordinates obtained from unprojection.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FociResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FOCI_RESAMPLE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-foci-resample")
    cargs.append(execution.input_file(foci_in))
    cargs.append(foci_out)
    if left_surfaces is not None:
        cargs.extend(left_surfaces.run(execution))
    if right_surfaces is not None:
        cargs.extend(right_surfaces.run(execution))
    if cerebellum_surfaces is not None:
        cargs.extend(cerebellum_surfaces.run(execution))
    if opt_discard_distance_from_surface:
        cargs.append("-discard-distance-from-surface")
    if opt_restore_xyz:
        cargs.append("-restore-xyz")
    ret = FociResampleOutputs(
        root=execution.output_file("."),
        foci_out=execution.output_file(foci_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FOCI_RESAMPLE_METADATA",
    "FociResampleCerebellumSurfaces",
    "FociResampleLeftSurfaces",
    "FociResampleOutputs",
    "FociResampleRightSurfaces",
    "foci_resample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CREATE_LUT_METADATA = Metadata(
    id="9f5316c7886385051e5fff290fb582380333101b.boutiques",
    name="create_lut",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class CreateLutOutputs(typing.NamedTuple):
    """
    Output object returned when calling `create_lut(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Generated lookup table files"""


def create_lut(
    output_file_root: str,
    runner: Runner | None = None,
) -> CreateLutOutputs:
    """
    A tool to create lookup tables.
    
    Args:
        output_file_root: The root name of the output file to be generated.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CreateLutOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CREATE_LUT_METADATA)
    cargs = []
    cargs.append("create_lut")
    cargs.append(output_file_root)
    ret = CreateLutOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(output_file_root + ".*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CREATE_LUT_METADATA",
    "CreateLutOutputs",
    "create_lut",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MULTIPLY_IMAGES_METADATA = Metadata(
    id="33f54529d3b0ca62abce96ec3a46f1a5f1f34ff3.boutiques",
    name="multiply_images",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class MultiplyImagesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `multiply_images(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_product_image_outfile: OutputPathType
    """Average image file."""


def multiply_images(
    dimension: typing.Literal[3, 2],
    first_input: InputPathType,
    output_product_image: InputPathType,
    second_input_2: float | None = None,
    num_threads: int | None = 1,
    runner: Runner | None = None,
) -> MultiplyImagesOutputs:
    """
    Multiply 2 images; 2nd image file may also be floating point numerical value,
    and program will act accordingly -- i.e. read as a number. Program handles
    vector and tensor images as well.
    
    Author: Advanced Normalization Tools (ANTs) Contributors
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dimension: 3 or 2. Image dimension (2 or 3).
        first_input: Image 1.
        output_product_image: Outputfname.nii.gz: the name of the resulting\
            image.
        second_input_2: file or string or a float. Image 2 or multiplication\
            weight.
        num_threads: Number of itk threads to use.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MultiplyImagesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MULTIPLY_IMAGES_METADATA)
    cargs = []
    cargs.append("MultiplyImages")
    cargs.append(str(dimension))
    cargs.append(execution.input_file(first_input))
    if second_input_2 is not None:
        cargs.append(str(second_input_2))
    cargs.append(execution.input_file(output_product_image))
    if num_threads is not None:
        cargs.append(str(num_threads))
    ret = MultiplyImagesOutputs(
        root=execution.output_file("."),
        output_product_image_outfile=execution.output_file(pathlib.Path(output_product_image).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MULTIPLY_IMAGES_METADATA",
    "MultiplyImagesOutputs",
    "multiply_images",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ERRTS_CORMAT_METADATA = Metadata(
    id="041ce1cbe7030e9af02420caf899590e04d99081.boutiques",
    name="3dErrtsCormat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dErrtsCormatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_errts_cormat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """1D file of the Toeplitz entries."""


def v_3d_errts_cormat(
    dset: InputPathType,
    runner: Runner | None = None,
) -> V3dErrtsCormatOutputs:
    """
    Computes the correlation matrix corresponding to the residual (or error) time
    series in 'dset'.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dErrtsCormat.html
    
    Args:
        dset: Dataset to read, usually the '-errts' output from 3dDeconvolve.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dErrtsCormatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ERRTS_CORMAT_METADATA)
    cargs = []
    cargs.append("3dErrtsCormat")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(dset))
    ret = V3dErrtsCormatOutputs(
        root=execution.output_file("."),
        output=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dErrtsCormatOutputs",
    "V_3D_ERRTS_CORMAT_METADATA",
    "v_3d_errts_cormat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIRST_UTILS_METADATA = Metadata(
    id="ddadf7ecb37493fd4432721f51af29a24ce03807.boutiques",
    name="first_utils",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FirstUtilsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `first_utils(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def first_utils(
    input_file: InputPathType,
    output_name: str,
    runner: Runner | None = None,
) -> FirstUtilsOutputs:
    """
    Utilities for handling FIRST's input and output files.
    
    Author: University of Oxford (Brian Patenaude)
    
    Args:
        input_file: Filename of input image/mesh/bvars.
        output_name: Output name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FirstUtilsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIRST_UTILS_METADATA)
    cargs = []
    cargs.append("first_utils")
    cargs.append("[OPTIONAL_ARGS]")
    cargs.append("-i")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.append("-o")
    cargs.extend([
        "-o",
        output_name
    ])
    ret = FirstUtilsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIRST_UTILS_METADATA",
    "FirstUtilsOutputs",
    "first_utils",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ASL_FILE_METADATA = Metadata(
    id="28db3b82c65c8920bf2c0aca64477d1ff9c01fbc.boutiques",
    name="asl_file",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class AslFileOutputs(typing.NamedTuple):
    """
    Output object returned when calling `asl_file(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_data: OutputPathType
    """Primary output data file"""
    output_mean: OutputPathType
    """Mean output data file"""


def asl_file(
    datafile: InputPathType,
    ntis: float,
    outfile: str,
    mask: InputPathType | None = None,
    inblockform: typing.Literal["rpt", "tis"] | None = None,
    inaslform: typing.Literal["diff", "tc", "ct", "tcb", "ctb"] | None = "diff",
    rpts: str | None = None,
    pairs: bool = False,
    spairs: bool = False,
    diff: bool = False,
    surrdiff: bool = False,
    extrapolate: bool = False,
    neighbour: float | None = None,
    pvgm: InputPathType | None = None,
    pvwm: InputPathType | None = None,
    kernel: float | None = None,
    outblockform: typing.Literal["rpt", "tis"] | None = None,
    mean_: bool = False,
    split: str | None = None,
    epoch: bool = False,
    epoch_length: float | None = None,
    epoch_overlap: float | None = None,
    epoch_unit: typing.Literal["rpt", "tis"] | None = None,
    deconv: bool = False,
    aif: InputPathType | None = None,
    runner: Runner | None = None,
) -> AslFileOutputs:
    """
    ASL data manipulation tool for FSL.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/AslFile
    
    Args:
        datafile: ASL data file.
        ntis: Number of TIs in the file.
        outfile: Output data file.
        mask: Mask file.
        inblockform: Input block format.
        inaslform: ASL data form.
        rpts: Number of repeats at each TI as comma separated list, not\
            required if the number of repeats is same for all TIs (only for use\
            with --ibf=tis).
        pairs: Data contains adjacent pairs of measurements (e.g. Tag, Control)\
            DEPRECATED use --iaf instead.
        spairs: Split the pairs within the data, e.g. to separate tag and\
            control images in output.
        diff: Take the difference between the pairs, i.e., Tag-control\
            difference.
        surrdiff: Do surround subtraction on the pairs.
        extrapolate: Option to extrapolate the edge of the brain to fix the\
            artefact on the edge of the brain.
        neighbour: Neighbour size for extrapolation, must be an odd number\
            between 3 and 9. Default: 5.
        pvgm: GM partial volume map.
        pvwm: WM partial volume map.
        kernel: Kernel size (in voxels) of partial volume correction, must be\
            an odd number between 3 and 9. Default: 5.
        outblockform: Output block format.
        mean_: Output ASL data having taken mean at each TI to file.
        split: Split data into separate files for each TI, specify filename\
            root.
        epoch: Output epochs of ASL data (takes mean at each TI within the\
            epoch).
        epoch_length: Length of epochs in number of repeats.
        epoch_overlap: Amount of overlap between epochs in number of repeats.
        epoch_unit: Epochs to be determined over.
        deconv: Deconvolution of data with arterial input functions.
        aif: Arterial input functions for deconvolution (4D volume, one aif for\
            each voxel within mask).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AslFileOutputs`).
    """
    if neighbour is not None and not (3 <= neighbour <= 9): 
        raise ValueError(f"'neighbour' must be between 3 <= x <= 9 but was {neighbour}")
    if kernel is not None and not (3 <= kernel <= 9): 
        raise ValueError(f"'kernel' must be between 3 <= x <= 9 but was {kernel}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(ASL_FILE_METADATA)
    cargs = []
    cargs.append("asl_file")
    cargs.extend([
        "--data",
        execution.input_file(datafile)
    ])
    cargs.extend([
        "--ntis",
        str(ntis)
    ])
    if mask is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask)
        ])
    if inblockform is not None:
        cargs.extend([
            "--ibf",
            inblockform
        ])
    if inaslform is not None:
        cargs.extend([
            "--iaf",
            inaslform
        ])
    if rpts is not None:
        cargs.extend([
            "--rpts",
            rpts
        ])
    if pairs:
        cargs.append("--pairs")
    if spairs:
        cargs.append("--spairs")
    if diff:
        cargs.append("--diff")
    if surrdiff:
        cargs.append("--surrdiff")
    if extrapolate:
        cargs.append("--extrapolate")
    if neighbour is not None:
        cargs.extend([
            "--neighbour",
            str(neighbour)
        ])
    if pvgm is not None:
        cargs.extend([
            "--pvgm",
            execution.input_file(pvgm)
        ])
    if pvwm is not None:
        cargs.extend([
            "--pvwm",
            execution.input_file(pvwm)
        ])
    if kernel is not None:
        cargs.extend([
            "--kernel",
            str(kernel)
        ])
    cargs.extend([
        "--out",
        outfile
    ])
    if outblockform is not None:
        cargs.extend([
            "--obf",
            outblockform
        ])
    if mean_:
        cargs.append("--mean")
    if split is not None:
        cargs.extend([
            "--split",
            split
        ])
    if epoch:
        cargs.append("--epoch")
    if epoch_length is not None:
        cargs.extend([
            "--elen",
            str(epoch_length)
        ])
    if epoch_overlap is not None:
        cargs.extend([
            "--eol",
            str(epoch_overlap)
        ])
    if epoch_unit is not None:
        cargs.extend([
            "--eunit",
            epoch_unit
        ])
    if deconv:
        cargs.append("--deconv")
    if aif is not None:
        cargs.extend([
            "--aif",
            execution.input_file(aif)
        ])
    ret = AslFileOutputs(
        root=execution.output_file("."),
        output_data=execution.output_file(outfile + ".nii.gz"),
        output_mean=execution.output_file(outfile + "_mean.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ASL_FILE_METADATA",
    "AslFileOutputs",
    "asl_file",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_MAT_SEL_PY_METADATA = Metadata(
    id="7d57915d94e233ae332e06d9062f43d9600ec66d.boutiques",
    name="fat_mat_sel.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatMatSelPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_mat_sel_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    individual_images: OutputPathType
    """Individual images of matrix plots."""
    matrix_grids: OutputPathType
    """Output matrix grid files."""
    v_1_d_dsets: OutputPathType
    """Output 1D dataset files."""


def fat_mat_sel_py(
    runner: Runner | None = None,
) -> FatMatSelPyOutputs:
    """
    Perform simple matrix plotting operations from outputs of FATCAT programs
    3dNetCorr and 3dTrackID.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/fat_mat_sel.py.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatMatSelPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_MAT_SEL_PY_METADATA)
    cargs = []
    cargs.append("fat_mat_sel.py")
    cargs.append("[--Pars=Pars]")
    cargs.append("[--matr_in=MATR_FILES]")
    cargs.append("[--list_match=LIST]")
    cargs.append("[--out_ind_matr]")
    cargs.append("[--Out_ind_1ddset]")
    cargs.append("[--Hold_image]")
    cargs.append("[--ExternLabsNo]")
    cargs.append("[--type_file=TYPE]")
    cargs.append("[--dpi_file=DPI]")
    cargs.append("[--xlen_file=LX]")
    cargs.append("[--ylen_file=LY]")
    cargs.append("[--Tight_layout_on]")
    cargs.append("[--Fig_off]")
    cargs.append("[--Size_font=S]")
    cargs.append("[--Lab_size_font=S]")
    cargs.append("[--A_plotmin=MIN]")
    cargs.append("[--B_plotmax=MAX]")
    cargs.append("[--Cbar_off]")
    cargs.append("[--Map_of_colors=MAP]")
    cargs.append("[--cbar_int_num=N]")
    cargs.append("[--width_cbar_perc=W]")
    cargs.append("[--specifier=STR]")
    cargs.append("[--Xtick_lab_off]")
    ret = FatMatSelPyOutputs(
        root=execution.output_file("."),
        individual_images=execution.output_file("individual_images/*"),
        matrix_grids=execution.output_file("matrix_grids/*"),
        v_1_d_dsets=execution.output_file("1D_dsets/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_MAT_SEL_PY_METADATA",
    "FatMatSelPyOutputs",
    "fat_mat_sel_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INVWARP_EXE_METADATA = Metadata(
    id="175b4b96a3fda73dd36df21eb780dd0c523a387b.boutiques",
    name="invwarp_exe",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class InvwarpExeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `invwarp_exe(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_inverse_warped_image: OutputPathType
    """Output inverse warped image"""


def invwarp_exe(
    warp_file: InputPathType,
    out_file: str,
    ref_file: InputPathType,
    rel_flag: bool = False,
    abs_flag: bool = False,
    niter: float | None = None,
    regularise: float | None = 1.0,
    initwarp: InputPathType | None = None,
    noconstraint: bool = False,
    jmin: float | None = 0.01,
    jmax: float | None = 100.0,
    debug_flag: bool = False,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> InvwarpExeOutputs:
    """
    Inverse warp image volume using FSL's invwarp tool.
    
    Author: University of Oxford (Mark Jenkinson)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FNIRT/UsersGuide#A--invwarp
    
    Args:
        warp_file: Filename for warp/shiftmap transform (volume).
        out_file: Filename for output (inverse warped) image.
        ref_file: Filename for new reference image, i.e., what was originally\
            the input image (determines inverse warpvol's FOV and pixdims).
        rel_flag: Use relative warp convention: x' = x + w(x).
        abs_flag: Use absolute warp convention (default): x' = w(x).
        niter: Number of gradient-descent iterations (default=10).
        regularise: Regularisation strength (default=1.0).
        initwarp: Filename for initial warp transform (volume).
        noconstraint: Do not apply the Jacobian constraint.
        jmin: Minimum acceptable Jacobian value for constraint (default 0.01).
        jmax: Maximum acceptable Jacobian value for constraint (default 100.0).
        debug_flag: Turn on debugging output.
        verbose_flag: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InvwarpExeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INVWARP_EXE_METADATA)
    cargs = []
    cargs.append("invwarp")
    cargs.append("-w")
    cargs.extend([
        "-w",
        execution.input_file(warp_file)
    ])
    cargs.append("-o")
    cargs.extend([
        "-o",
        out_file
    ])
    cargs.append("-r")
    cargs.extend([
        "-r",
        execution.input_file(ref_file)
    ])
    if rel_flag:
        cargs.append("--rel")
    if abs_flag:
        cargs.append("--abs")
    if niter is not None:
        cargs.extend([
            "-n",
            str(niter)
        ])
    if regularise is not None:
        cargs.extend([
            "--regularise",
            str(regularise)
        ])
    if initwarp is not None:
        cargs.extend([
            "--initwarp",
            execution.input_file(initwarp)
        ])
    if noconstraint:
        cargs.append("--noconstraint")
    if jmin is not None:
        cargs.extend([
            "--jmin",
            str(jmin)
        ])
    if jmax is not None:
        cargs.extend([
            "--jmax",
            str(jmax)
        ])
    if debug_flag:
        cargs.append("--debug")
    if verbose_flag:
        cargs.append("-v")
    ret = InvwarpExeOutputs(
        root=execution.output_file("."),
        output_inverse_warped_image=execution.output_file(out_file + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INVWARP_EXE_METADATA",
    "InvwarpExeOutputs",
    "invwarp_exe",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TCORR1_D_METADATA = Metadata(
    id="53f15459103ea70fcda0ae8a21f3ca2a54b306a0.boutiques",
    name="3dTcorr1D",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTcorr1DOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tcorr1_d(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output filename prefix."""
    out_file_: OutputPathType
    """Output file containing correlations."""


def v_3d_tcorr1_d(
    xset: InputPathType,
    y_1d: InputPathType,
    spearman: bool = False,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    runner: Runner | None = None,
) -> V3dTcorr1DOutputs:
    """
    Computes the correlation coefficient between each voxel time series in the input
    3D+time dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTcorr1D.html
    
    Args:
        xset: 3d+time dataset input.
        y_1d: 1d time series file input.
        spearman: Correlation is the spearman (rank) correlation coefficient.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTcorr1DOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TCORR1_D_METADATA)
    cargs = []
    cargs.append("3dTcorr1D")
    cargs.append(execution.input_file(xset))
    if spearman:
        cargs.append("-spearman")
    cargs.append(execution.input_file(y_1d))
    cargs.append("[OUT_FILE]")
    if outputtype is not None:
        cargs.append(outputtype)
    ret = V3dTcorr1DOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(xset).name + "_correlation.nii.gz"),
        out_file_=execution.output_file("out_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTcorr1DOutputs",
    "V_3D_TCORR1_D_METADATA",
    "v_3d_tcorr1_d",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMAVER_METADATA = Metadata(
    id="3251542a62df461a6a7151ca506b64c9358fa1cf.boutiques",
    name="imaver",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ImaverOutputs(typing.NamedTuple):
    """
    Output object returned when calling `imaver(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_ave_output: OutputPathType | None
    """Output image file for averages (optional)"""
    out_sig_output: OutputPathType | None
    """Output image file for standard deviations (optional)"""


def imaver(
    input_images: list[InputPathType],
    out_ave: str | None = None,
    out_sig: str | None = None,
    runner: Runner | None = None,
) -> ImaverOutputs:
    """
    Computes the mean and standard deviation, pixel-by-pixel, of a whole bunch of
    images.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/imaver.html
    
    Args:
        input_images: Input image files for processing.
        out_ave: Output average image file. Use '-' to skip output.
        out_sig: Output standard deviation image file. Use '-' to skip output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImaverOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMAVER_METADATA)
    cargs = []
    cargs.append("imaver")
    if out_ave is not None:
        cargs.append(out_ave)
    if out_sig is not None:
        cargs.append(out_sig)
    cargs.extend([execution.input_file(f) for f in input_images])
    ret = ImaverOutputs(
        root=execution.output_file("."),
        out_ave_output=execution.output_file(out_ave) if (out_ave is not None) else None,
        out_sig_output=execution.output_file(out_sig) if (out_sig is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMAVER_METADATA",
    "ImaverOutputs",
    "imaver",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SIGNAL2IMAGE_METADATA = Metadata(
    id="ee51e599579afe1ad9e1eb37382cd7781755836a.boutiques",
    name="signal2image",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Signal2imageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `signal2image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType | None
    """The resultant image file from the input signal and pulse sequence."""
    kspace_outfile: OutputPathType | None
    """The resultant k-space file."""


def signal2image(
    pulse_sequence: InputPathType,
    input_signal: InputPathType | None = None,
    output_image: str | None = None,
    kspace_coordinates: InputPathType | None = None,
    output_kspace: str | None = None,
    abs_flag: bool = False,
    homodyne_flag: bool = False,
    verbose_flag: bool = False,
    apodize_flag: bool = False,
    cutoff: float | None = 100,
    rolloff: float | None = 10,
    save_flag: bool = False,
    runner: Runner | None = None,
) -> Signal2imageOutputs:
    """
    A tool for converting MR signal data to images using specified k-space
    coordinates and pulse sequences.
    
    Author: University of Oxford (Mark Jenkinson & Ivana Drobnjak)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/
    
    Args:
        pulse_sequence: 8-column pulse_sequence matrix. Expects to find all\
            other pulse sequence files in the same directory.
        input_signal: Input signal file.
        output_image: Output image file.
        kspace_coordinates: K-space coordinates file.
        output_kspace: Output k-space file.
        abs_flag: Save absolute magnitude and phase.
        homodyne_flag: Do the homodyne reconstruction.
        verbose_flag: Switch on diagnostic messages.
        apodize_flag: Do apodization.
        cutoff: Apodization with this cutoff; default 100.
        rolloff: Apodization with this rolloff; default 10.
        save_flag: Save window as ASCII matrix (DEBUG!).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Signal2imageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SIGNAL2IMAGE_METADATA)
    cargs = []
    cargs.append("signal2image")
    cargs.extend([
        "-p",
        execution.input_file(pulse_sequence)
    ])
    if input_signal is not None:
        cargs.extend([
            "-i",
            execution.input_file(input_signal)
        ])
    if output_image is not None:
        cargs.extend([
            "-o",
            output_image
        ])
    if kspace_coordinates is not None:
        cargs.extend([
            "-c",
            execution.input_file(kspace_coordinates)
        ])
    if output_kspace is not None:
        cargs.extend([
            "-k",
            output_kspace
        ])
    if abs_flag:
        cargs.append("-a")
    if homodyne_flag:
        cargs.append("--homo")
    if verbose_flag:
        cargs.append("-v")
    if apodize_flag:
        cargs.append("-z")
    if cutoff is not None:
        cargs.extend([
            "-l",
            str(cutoff)
        ])
    if rolloff is not None:
        cargs.extend([
            "-r",
            str(rolloff)
        ])
    if save_flag:
        cargs.append("-s")
    ret = Signal2imageOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(output_image) if (output_image is not None) else None,
        kspace_outfile=execution.output_file(output_kspace) if (output_kspace is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SIGNAL2IMAGE_METADATA",
    "Signal2imageOutputs",
    "signal2image",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SUMA_ACKNOWLEDGE_METADATA = Metadata(
    id="28d6a23c7c01c95dbd5de9857c095cd6ca4e2fe5.boutiques",
    name="@suma_acknowledge",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSumaAcknowledgeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__suma_acknowledge(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output graph dataset"""


def v__suma_acknowledge(
    input_file: InputPathType,
    surface_file: InputPathType,
    output_prefix: str,
    center_flag: bool = False,
    subsurface_file: str | None = None,
    scale_factor: float | None = None,
    reduce_factor: float | None = None,
    runner: Runner | None = None,
) -> VSumaAcknowledgeOutputs:
    """
    Demo script to create a graph dataset to show names of individuals and groups,
    potentially useful for acknowledgements in a talk.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@suma_acknowledge.html
    
    Args:
        input_file: Required input text file with format for each line: first\
            last groupname.
        surface_file: Required surface to place nodes.
        output_prefix: Output prefix for graph dataset.
        center_flag: Put center coord at x,y,z=0,0,0. Otherwise, uses average\
            xyz in surface.
        subsurface_file: Surface for surrounding members of group (use ld2,\
            ld4, ld5, ld6, .... default is ld5).
        scale_factor: Scale xyz for group nodes (default is 1.0).
        reduce_factor: Scale xyz offsets for member nodes (xyz/r), default is\
            10.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSumaAcknowledgeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SUMA_ACKNOWLEDGE_METADATA)
    cargs = []
    cargs.append("@suma_acknowledge")
    cargs.append("-input")
    cargs.append(execution.input_file(input_file))
    cargs.append("-surf")
    cargs.append(execution.input_file(surface_file))
    cargs.append("-prefix")
    cargs.append(output_prefix)
    if center_flag:
        cargs.append("-center")
    if subsurface_file is not None:
        cargs.extend([
            "-subsurf",
            subsurface_file
        ])
    if scale_factor is not None:
        cargs.extend([
            "-scalefactor",
            str(scale_factor)
        ])
    if reduce_factor is not None:
        cargs.extend([
            "-reducefactor",
            str(reduce_factor)
        ])
    ret = VSumaAcknowledgeOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_prefix + "_graph_dataset"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSumaAcknowledgeOutputs",
    "V__SUMA_ACKNOWLEDGE_METADATA",
    "v__suma_acknowledge",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_QWARP_METADATA = Metadata(
    id="862e17640b27936f88c1ff1e669f35719de1ac81.boutiques",
    name="3dQwarp",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dQwarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_qwarp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    warped_dataset: OutputPathType
    """Warped dataset"""
    warp_dataset: OutputPathType
    """Warp dataset"""
    inverse_warp_dataset: OutputPathType
    """Inverse warp dataset"""


def v_3d_qwarp(
    base_dataset: InputPathType,
    source_dataset: InputPathType,
    prefix: str,
    runner: Runner | None = None,
) -> V3dQwarpOutputs:
    """
    Computes a nonlinearly warped version of source_dataset to match base_dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dQwarp.html
    
    Args:
        base_dataset: Base dataset.
        source_dataset: Source dataset.
        prefix: Prefix for the output datasets.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dQwarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_QWARP_METADATA)
    cargs = []
    cargs.append("3dQwarp")
    cargs.append("-base")
    cargs.append(execution.input_file(base_dataset))
    cargs.append("-source")
    cargs.append(execution.input_file(source_dataset))
    cargs.append("-prefix")
    cargs.append(prefix)
    cargs.append("[OPTIONS]")
    ret = V3dQwarpOutputs(
        root=execution.output_file("."),
        warped_dataset=execution.output_file("{PREFIX}+tlrc"),
        warp_dataset=execution.output_file("{PREFIX}_WARP+tlrc"),
        inverse_warp_dataset=execution.output_file("{PREFIX}_WARPINV+tlrc"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dQwarpOutputs",
    "V_3D_QWARP_METADATA",
    "v_3d_qwarp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TIMING_TOOL_PY_METADATA = Metadata(
    id="44a18ee84951e77612dd8bc063de7bce71b77863.boutiques",
    name="timing_tool.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class TimingToolPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `timing_tool_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_timing_file: OutputPathType
    """Output timing file as specified"""
    timing_to_1_d_output: OutputPathType
    """Output 1D formatted stimulus data"""


def timing_tool_py(
    runner: Runner | None = None,
) -> TimingToolPyOutputs:
    """
    Tool for manipulating and evaluating stimulus timing files.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/timing_tool.py.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TimingToolPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TIMING_TOOL_PY_METADATA)
    cargs = []
    cargs.append("timing_tool.py")
    cargs.append("[COMMANDS]")
    ret = TimingToolPyOutputs(
        root=execution.output_file("."),
        output_timing_file=execution.output_file("[OUTPUT_FILE]"),
        timing_to_1_d_output=execution.output_file("[TIMING_TO_1D_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TIMING_TOOL_PY_METADATA",
    "TimingToolPyOutputs",
    "timing_tool_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_ERODE_METADATA = Metadata(
    id="10a4eb40c2a7f0a9ed7b519b27c5709c07c5bc8b.boutiques",
    name="volume-erode",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class VolumeErodeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_erode(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_erode(
    volume: InputPathType,
    distance: float,
    volume_out: str,
    opt_roi_roi_volume: InputPathType | None = None,
    opt_subvolume_subvol: str | None = None,
    runner: Runner | None = None,
) -> VolumeErodeOutputs:
    """
    Erode a volume file.
    
    Around each voxel with a value of zero, set surrounding voxels to zero. The
    surrounding voxels are all face neighbors and all voxels within the
    specified distance (center to center).
    
    Author: Washington University School of Medicin
    
    Args:
        volume: the volume to erode.
        distance: distance in mm to erode.
        volume_out: the output volume.
        opt_roi_roi_volume: assume voxels outside this roi are nonzero: volume\
            file, positive values denote voxels that have data.
        opt_subvolume_subvol: select a single subvolume to dilate: the\
            subvolume number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeErodeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_ERODE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-erode")
    cargs.append(execution.input_file(volume))
    cargs.append(str(distance))
    cargs.append(volume_out)
    if opt_roi_roi_volume is not None:
        cargs.extend([
            "-roi",
            execution.input_file(opt_roi_roi_volume)
        ])
    if opt_subvolume_subvol is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvol
        ])
    ret = VolumeErodeOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_ERODE_METADATA",
    "VolumeErodeOutputs",
    "volume_erode",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DUAL_REGRESSION_METADATA = Metadata(
    id="95f84773f4d62fa0b64c509d5010765d2f9809b3.boutiques",
    name="dual_regression",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class DualRegressionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dual_regression(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stage1_output: OutputPathType
    """Output from stage 1 for each subject"""
    stage2_output: OutputPathType
    """Output from stage 2 for each subject"""
    stage3_output: OutputPathType
    """Output from stage 3 for each subject"""
    randomise_output: OutputPathType
    """Output of randomise"""


def dual_regression(
    group_ic_maps: InputPathType,
    des_norm: float,
    design_mat: InputPathType,
    design_con: InputPathType,
    n_perm: float,
    output_directory: str,
    input_files: list[InputPathType],
    thr_flag: bool = False,
    runner: Runner | None = None,
) -> DualRegressionOutputs:
    """
    Dual regression algorithm to investigate group-ICA results.
    
    Author: FMRIB Analysis Group
    
    URL: https://fsl.fmrib.ox.ac.uk/
    
    Args:
        group_ic_maps: 4D image containing spatial IC maps (melodic_IC) from\
            the whole-group ICA analysis.
        des_norm: 0 or 1 (1 is recommended). Whether to variance-normalise the\
            timecourses used as the stage-2 regressors.
        design_mat: Design matrix for final cross-subject modelling with\
            randomise.
        design_con: Design contrasts for final cross-subject modelling with\
            randomise.
        n_perm: Number of permutations for randomise; set to 1 for just raw\
            tstat output, set to 0 to not run randomise at all.
        output_directory: This directory will be created to hold all output and\
            logfiles.
        input_files: List of all subjects' preprocessed, standard-space 4D\
            datasets.
        thr_flag: Perform thresholded dual regression to obtain unbiased\
            timeseries for connectomics analyses (e.g., with FSLnets).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DualRegressionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DUAL_REGRESSION_METADATA)
    cargs = []
    cargs.append("dual_regression")
    cargs.append(execution.input_file(group_ic_maps))
    cargs.append(str(des_norm))
    cargs.append(execution.input_file(design_mat))
    cargs.append(execution.input_file(design_con))
    cargs.append(str(n_perm))
    if thr_flag:
        cargs.append("--thr")
    cargs.append(output_directory)
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = DualRegressionOutputs(
        root=execution.output_file("."),
        stage1_output=execution.output_file(output_directory + "/dr_stage1_subject[SUBJECT_INDEX].nii.gz"),
        stage2_output=execution.output_file(output_directory + "/dr_stage2_subject[SUBJECT_INDEX].nii.gz"),
        stage3_output=execution.output_file(output_directory + "/dr_stage3_subject[SUBJECT_INDEX].nii.gz"),
        randomise_output=execution.output_file(output_directory + "/dr_randomise"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DUAL_REGRESSION_METADATA",
    "DualRegressionOutputs",
    "dual_regression",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLSWAPDIM_EXE_METADATA = Metadata(
    id="93c7959520f237ffe1f1d4f37145c2da413b31cf.boutiques",
    name="fslswapdim_exe",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslswapdimExeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslswapdim_exe(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType | None
    """Output image file with swapped dimensions"""


def fslswapdim_exe(
    input_file: InputPathType,
    axis_a: str,
    axis_b: str,
    axis_c: str,
    output_file: InputPathType | None = None,
    check_lr_flag: bool = False,
    runner: Runner | None = None,
) -> FslswapdimExeOutputs:
    """
    Tool to swap the x, y, z axes dimensions of an image.
    
    Author: FMRIB Centre, Oxford University
    
    Args:
        input_file: Input image file (e.g., input.nii.gz).
        axis_a: New x-axis in terms of old axes (-x, x, y, -y, z, -z).
        axis_b: New y-axis in terms of old axes (-x, x, y, -y, z, -z).
        axis_c: New z-axis in terms of old axes (-x, x, y, -y, z, -z).
        output_file: Output image file (optional, cannot be used with --checkLR\
            flag).
        check_lr_flag: Option to check if the specified arguments lead to a\
            Left-Right swap or not, cannot be used with an output name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslswapdimExeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLSWAPDIM_EXE_METADATA)
    cargs = []
    cargs.append("fslswapdim_exe")
    cargs.append(execution.input_file(input_file))
    cargs.append(axis_a)
    cargs.append(axis_b)
    cargs.append(axis_c)
    if output_file is not None:
        cargs.append(execution.input_file(output_file))
    if check_lr_flag:
        cargs.append("--checkLR")
    ret = FslswapdimExeOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(pathlib.Path(output_file).name) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLSWAPDIM_EXE_METADATA",
    "FslswapdimExeOutputs",
    "fslswapdim_exe",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MSE_METADATA = Metadata(
    id="b74f6f494637c16d5078c837bc3d468846ae086a.boutiques",
    name="3dMSE",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_mse(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_brik: OutputPathType | None
    """Output dataset in BRIK format."""
    out_head: OutputPathType | None
    """Output dataset in HEAD format."""


def v_3d_mse(
    dset: InputPathType,
    polynomial_order: int | None = None,
    autoclip: bool = False,
    automask: bool = False,
    mask: InputPathType | None = None,
    prefix: str | None = None,
    scales: float | None = None,
    entwin: float | None = None,
    rthresh: float | None = None,
    runner: Runner | None = None,
) -> V3dMseOutputs:
    """
    Computes voxelwise multi-scale entropy.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dMSE.html
    
    Args:
        dset: Input dataset (e.g., dset.nii.gz).
        polynomial_order: Remove polynomial trend of order 'm' (default is m=1;\
            m=-1 means no detrending).
        autoclip: Clip off low-intensity regions in the dataset.
        automask: Use automask to clip low-intensity regions.
        mask: Mask to define 'in-brain' voxels.
        prefix: Prefix for the output dataset (default is 'MSE').
        scales: The number of scales to be used in the calculation (default is\
            5).
        entwin: The window size used in the calculation (default is 2).
        rthresh: The radius threshold for determining if values are the same in\
            the SampleEn calculation, in fractions of the standard deviation\
            (default is 0.5).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMseOutputs`).
    """
    if polynomial_order is not None and not (-1 <= polynomial_order <= 3): 
        raise ValueError(f"'polynomial_order' must be between -1 <= x <= 3 but was {polynomial_order}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MSE_METADATA)
    cargs = []
    cargs.append("3dMSE")
    if polynomial_order is not None:
        cargs.extend([
            "-polort",
            str(polynomial_order)
        ])
    if autoclip:
        cargs.append("-autoclip")
    if automask:
        cargs.append("-automask")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if scales is not None:
        cargs.extend([
            "-scales",
            str(scales)
        ])
    if entwin is not None:
        cargs.extend([
            "-entwin",
            str(entwin)
        ])
    if rthresh is not None:
        cargs.extend([
            "-rthresh",
            str(rthresh)
        ])
    cargs.append(execution.input_file(dset))
    ret = V3dMseOutputs(
        root=execution.output_file("."),
        out_brik=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
        out_head=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMseOutputs",
    "V_3D_MSE_METADATA",
    "v_3d_mse",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ELECTRO_GRID_METADATA = Metadata(
    id="318e5f8b11b5381c4129ef2a10c897b952d8d454.boutiques",
    name="@ElectroGrid",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VElectroGridOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__electro_grid(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface: OutputPathType
    """Output surface file"""


def v__electro_grid(
    runner: Runner | None = None,
) -> VElectroGridOutputs:
    """
    Creates a mesh representation of an electrode grid for use with SUMA.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@ElectroGrid.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VElectroGridOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ELECTRO_GRID_METADATA)
    cargs = []
    cargs.append("@ElectroGrid")
    cargs.append("[[-strip")
    cargs.append("Nx]")
    cargs.append("|")
    cargs.append("[-grid")
    cargs.append("Nx")
    cargs.append("Ny]]")
    cargs.append("[-prefix")
    cargs.append("PREFIX]")
    cargs.append("[-coords")
    cargs.append("XYZ.1D]")
    cargs.append("[-with_markers]")
    cargs.append("[-echo]")
    ret = VElectroGridOutputs(
        root=execution.output_file("."),
        output_surface=execution.output_file("[PREFIX].gii"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VElectroGridOutputs",
    "V__ELECTRO_GRID_METADATA",
    "v__electro_grid",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ECM_METADATA = Metadata(
    id="44c6a60ac060c4ce8eb6c9f327ae7672557ef517.boutiques",
    name="3dECM",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dEcmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_ecm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output image file name."""
    out_file_: OutputPathType
    """Output file."""


def v_3d_ecm(
    in_file: InputPathType,
    autoclip: bool = False,
    automask: bool = False,
    eps: float | None = None,
    fecm: bool = False,
    full: bool = False,
    mask: InputPathType | None = None,
    max_iter: int | None = None,
    memory: float | None = None,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    polort: int | None = None,
    scale: float | None = None,
    shift: float | None = None,
    sparsity: float | None = None,
    thresh: float | None = None,
    runner: Runner | None = None,
) -> V3dEcmOutputs:
    """
    Performs degree centrality on a dataset using a given maskfile via the 3dECM
    command.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dECM.html
    
    Args:
        in_file: Input file to 3decm.
        autoclip: Clip off low-intensity regions in the dataset.
        automask: Mask the dataset to target brain-only voxels.
        eps: Sets the stopping criterion for the power iteration;\
            :math:`l2\|v_\text{old} - v_\text{new}\| < eps\|v_\text{old}\|`;\
            default = 0.001.
        fecm: Fast centrality method; substantial speed increase but cannot\
            accommodate thresholding; automatically selected if -thresh or\
            -sparsity are not set.
        full: Full power method; enables thresholding; automatically selected\
            if -thresh or -sparsity are set.
        mask: Mask file to mask input data.
        max_iter: Sets the maximum number of iterations to use in the power\
            iteration; default = 1000.
        memory: Limit memory consumption on system by setting the amount of gb\
            to limit the algorithm to; default = 2gb.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        polort: No description provided.
        scale: Scale correlation coefficients in similarity matrix to after\
            shifting, x >= 0.0; default = 1.0 for -full, 0.5 for -fecm.
        shift: Shift correlation coefficients in similarity matrix to enforce\
            non-negativity, s >= 0.0; default = 0.0 for -full, 1.0 for -fecm.
        sparsity: Only take the top percent of connections.
        thresh: Threshold to exclude connections where corr <= thresh.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dEcmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ECM_METADATA)
    cargs = []
    cargs.append("3dECM")
    cargs.append(execution.input_file(in_file))
    if autoclip:
        cargs.append("-autoclip")
    if automask:
        cargs.append("-automask")
    if eps is not None:
        cargs.extend([
            "-eps",
            str(eps)
        ])
    if fecm:
        cargs.append("-fecm")
    if full:
        cargs.append("-full")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if max_iter is not None:
        cargs.extend([
            "-max_iter",
            str(max_iter)
        ])
    if memory is not None:
        cargs.extend([
            "-memory",
            str(memory)
        ])
    cargs.append("[OUT_FILE]")
    if outputtype is not None:
        cargs.append(outputtype)
    if polort is not None:
        cargs.extend([
            "-polort",
            str(polort)
        ])
    if scale is not None:
        cargs.extend([
            "-scale",
            str(scale)
        ])
    if shift is not None:
        cargs.extend([
            "-shift",
            str(shift)
        ])
    if sparsity is not None:
        cargs.extend([
            "-sparsity",
            str(sparsity)
        ])
    if thresh is not None:
        cargs.extend([
            "-thresh",
            str(thresh)
        ])
    ret = V3dEcmOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(in_file).name + "_afni"),
        out_file_=execution.output_file("out_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dEcmOutputs",
    "V_3D_ECM_METADATA",
    "v_3d_ecm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_DIST_METADATA = Metadata(
    id="ba51dd4f5e28dff9f90eeed0a06742c5cbdeb475.boutiques",
    name="SurfDist",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfDistOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_dist(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    distances: OutputPathType
    """File containing the distances between nodes"""


def surf_dist(
    surface: InputPathType,
    nodepairs: InputPathType,
    node_path_do: str | None = None,
    graph: bool = False,
    runner: Runner | None = None,
) -> SurfDistOutputs:
    """
    Calculate shortest distance between node pairs on a surface mesh.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfDist.html
    
    Args:
        surface: Surface on which distances are computed.
        nodepairs: Specify node pairs for distance computation.
        node_path_do: Output the shortest path between each node pair as a SUMA\
            Displayable object.
        graph: Calculate distance along the mesh (default).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfDistOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_DIST_METADATA)
    cargs = []
    cargs.append("SurfDist")
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(nodepairs))
    if node_path_do is not None:
        cargs.extend([
            "-node_path_do",
            node_path_do
        ])
    if graph:
        cargs.append("-graph")
    ret = SurfDistOutputs(
        root=execution.output_file("."),
        distances=execution.output_file("example.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_DIST_METADATA",
    "SurfDistOutputs",
    "surf_dist",
]
